@@ -2,14 +2,12 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 import getopt
 import os
 import sys
 import logging
-logging.basicConfig()
 
 from pcs import (
     acl,
@@ -31,9 +29,14 @@ from pcs import (
     alert,
 )
 
-from pcs.cli.common import completion
+from pcs.cli.common import (
+    capabilities,
+    completion,
+    parse_args,
+)
 
 
+logging.basicConfig()
 usefile = False
 filename = ""
 def main(argv=None):
@@ -49,90 +52,48 @@ def main(argv=None):
     global filename, usefile
     orig_argv = argv[:]
     utils.pcs_options = {}
-    modified_argv = []
-    real_argv = []
+
+    argv = parse_args.upgrade_args(argv)
+
+    # we want to support optional arguments for --wait, so if an argument
+    # is specified with --wait (ie. --wait=30) then we use them
+    waitsecs = None
+    new_argv = []
+    for arg in argv:
+        if arg.startswith("--wait="):
+            tempsecs = arg.replace("--wait=","")
+            if len(tempsecs) > 0:
+                waitsecs = tempsecs
+                arg = "--wait"
+        new_argv.append(arg)
+    argv = new_argv
+
     try:
-        # we change --cloneopt to "clone" for backwards compatibility
-        new_argv = []
-        for arg in argv:
-            if arg == "--cloneopt" or arg == "--clone":
-                new_argv.append("clone")
-            elif arg.startswith("--cloneopt="):
-                new_argv.append("clone")
-                new_argv.append(arg.split('=',1)[1])
-            else:
-                new_argv.append(arg)
-        argv = new_argv
-
-        # we want to support optional arguments for --wait, so if an argument
-        # is specified with --wait (ie. --wait=30) then we use them
-        waitsecs = None
-        new_argv = []
-        for arg in argv:
-            if arg.startswith("--wait="):
-                tempsecs = arg.replace("--wait=","")
-                if len(tempsecs) > 0:
-                    waitsecs = tempsecs
-                    arg = "--wait"
-            new_argv.append(arg)
-        argv = new_argv
-
-        # h = help, f = file,
-        # p = password (cluster auth), u = user (cluster auth),
-        # V = verbose (cluster verify)
-        pcs_short_options = "hf:p:u:V"
-        pcs_long_options = [
-            "debug", "version", "help", "fullhelp",
-            "force", "skip-offline", "autocorrect", "interactive", "autodelete",
-            "all", "full", "groups", "local", "wait", "config",
-            "start", "enable", "disabled", "off",
-            "pacemaker", "corosync",
-            "no-default-ops", "defaults", "nodesc",
-            "clone", "master", "name=", "group=", "node=",
-            "from=", "to=", "after=", "before=",
-            "transport=", "rrpmode=", "ipv6",
-            "addr0=", "bcast0=", "mcast0=", "mcastport0=", "ttl0=", "broadcast0",
-            "addr1=", "bcast1=", "mcast1=", "mcastport1=", "ttl1=", "broadcast1",
-            "wait_for_all=", "auto_tie_breaker=", "last_man_standing=",
-            "last_man_standing_window=",
-            "token=", "token_coefficient=", "consensus=", "join=",
-            "miss_count_const=", "fail_recv_const=",
-            "corosync_conf=", "cluster_conf=",
-            "booth-conf=", "booth-key=",
-            "remote", "watchdog=",
-            #in pcs status - do not display resorce status on inactive node
-            "hide-inactive",
-        ]
-        # pull out negative number arguments and add them back after getopt
-        prev_arg = ""
-        for arg in argv:
-            if len(arg) > 0 and arg[0] == "-":
-                if arg[1:].isdigit() or arg[1:].startswith("INFINITY"):
-                    real_argv.append(arg)
-                else:
-                    modified_argv.append(arg)
-            else:
-                # If previous argument required an argument, then this arg
-                # should not be added back in
-                if not prev_arg or (not (prev_arg[0] == "-" and prev_arg[1:] in pcs_short_options) and not (prev_arg[0:2] == "--" and (prev_arg[2:] + "=") in pcs_long_options)):
-                    real_argv.append(arg)
-                modified_argv.append(arg)
-            prev_arg = arg
-
-        pcs_options, argv = getopt.gnu_getopt(modified_argv, pcs_short_options, pcs_long_options)
+        pcs_options, dummy_argv = getopt.gnu_getopt(
+            parse_args.filter_out_non_option_negative_numbers(argv),
+            parse_args.PCS_SHORT_OPTIONS,
+            parse_args.PCS_LONG_OPTIONS,
+        )
     except getopt.GetoptError as err:
         print(err)
         usage.main()
         sys.exit(1)
-    argv = real_argv
+    argv = parse_args.filter_out_options(argv)
+
+    full = False
+    for option, dummy_value in pcs_options:
+        if option == "--full":
+            full = True
+            break
+
     for o, a in pcs_options:
         if not o in utils.pcs_options:
-            if o == "--watchdog":
+            if o in ["--watchdog", "--device"]:
                 a = [a]
             utils.pcs_options[o] = a
         else:
             # If any options are a list then they've been entered twice which isn't valid
-            if o != "--watchdog":
+            if o not in ["--watchdog", "--device"]:
                 utils.err("%s can only be used once" % o)
             else:
                 utils.pcs_options[o].append(a)
@@ -154,12 +115,35 @@ def main(argv=None):
             settings.cluster_conf_file = a
         elif o == "--version":
             print(settings.pcs_version)
+            if full:
+                print(" ".join(
+                    sorted([
+                        feat["id"]
+                        for feat in capabilities.get_pcs_capabilities()
+                    ])
+                ))
             sys.exit()
         elif o == "--fullhelp":
             usage.full_usage()
             sys.exit()
         elif o == "--wait":
             utils.pcs_options[o] = waitsecs
+        elif o == "--request-timeout":
+            request_timeout_valid = False
+            try:
+                timeout = int(a)
+                if timeout > 0:
+                    utils.pcs_options[o] = timeout
+                    request_timeout_valid = True
+            except ValueError:
+                pass
+            if not request_timeout_valid:
+                utils.err(
+                    (
+                        "'{0}' is not a valid --request-timeout value, use "
+                        "a positive integer"
+                    ).format(a)
+                )
 
     if len(argv) == 0:
         usage.main()
@@ -167,7 +151,7 @@ def main(argv=None):
 
     # create a dummy logger
     # we do not have a log file for cli (yet), but library requires a logger
-    logger = logging.getLogger("old_cli")
+    logger = logging.getLogger("pcs")
     logger.propagate = 0
     logger.handlers = []
 
@@ -184,31 +168,39 @@ def main(argv=None):
         "acl": lambda argv: acl.acl_cmd(
             utils.get_library_wrapper(),
             argv,
-            utils.get_modificators()
+            utils.get_modifiers()
+        ),
+        "status": lambda argv: status.status_cmd(
+            utils.get_library_wrapper(),
+            argv,
+            utils.get_modifiers()
         ),
-        "status": status.status_cmd,
         "config": config.config_cmd,
         "pcsd": pcsd.pcsd_cmd,
-        "node": node.node_cmd,
+        "node": lambda argv: node.node_cmd(
+            utils.get_library_wrapper(),
+            argv,
+            utils.get_modifiers()
+        ),
         "quorum": lambda argv: quorum.quorum_cmd(
             utils.get_library_wrapper(),
             argv,
-            utils.get_modificators()
+            utils.get_modifiers()
         ),
         "qdevice": lambda argv: qdevice.qdevice_cmd(
             utils.get_library_wrapper(),
             argv,
-            utils.get_modificators()
+            utils.get_modifiers()
         ),
         "alert": lambda args: alert.alert_cmd(
             utils.get_library_wrapper(),
             args,
-            utils.get_modificators()
+            utils.get_modifiers()
         ),
         "booth": lambda argv: booth.booth_cmd(
             utils.get_library_wrapper(),
             argv,
-            utils.get_modificators()
+            utils.get_modifiers()
         ),
     }
     if command not in cmd_map:
