@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 from collections import Iterable
@@ -16,6 +15,20 @@ from pcs.common.tools import is_string
 INSTANCE_SUFFIX = "@{0}"
 NODE_PREFIX = "{0}: "
 
+_type_translation = {
+    "acl_group": "ACL group",
+    "acl_permission": "ACL permission",
+    "acl_role": "ACL role",
+    "acl_target": "ACL user",
+    "primitive": "resource",
+}
+_type_articles = {
+    "ACL group": "an",
+    "ACL user": "an",
+    "ACL role": "an",
+    "ACL permission": "an",
+}
+
 def warn(message):
     sys.stdout.write(format_message(message, "Warning: "))
 
@@ -81,22 +94,30 @@ def service_operation_skipped(operation, info):
         **info
     )
 
+def typelist_to_string(type_list, article=False):
+    if not type_list:
+        return ""
+    new_list = sorted([
+        # get a translation or make a type_name a string
+        _type_translation.get(type_name, "{0}".format(type_name))
+        for type_name in type_list
+    ])
+    types = "/".join(new_list)
+    if not article:
+        return types
+    return "{article} {types}".format(
+        article=_type_articles.get(new_list[0], "a"),
+        types=types
+    )
+
 def id_belongs_to_unexpected_type(info):
-    translate_expected = {
-        "acl_group": "an acl group",
-        "acl_target": "an acl user",
-        "group": "a group",
-    }
     return "'{id}' is not {expected_type}".format(
         id=info["id"],
-        expected_type="/".join([
-            translate_expected.get(tag, "{0}".format(tag))
-            for tag in info["expected_types"]
-        ]),
+        expected_type=typelist_to_string(info["expected_types"], article=True)
     )
 
 def id_not_found(info):
-    desc = format_optional(info["id_description"], "{0} ")
+    desc = format_optional(typelist_to_string(info["expected_types"]), "{0} ")
     if not info["context_type"] or not info["context_id"]:
         return "{desc}'{id}' does not exist".format(desc=desc, id=info["id"])
 
@@ -132,6 +153,32 @@ def resource_running_on_nodes(info):
         ]))
     )
 
+def invalid_options(info):
+    template = "invalid {desc}option{plural_options} {option_names_list},"
+    if not info["allowed"] and not info["allowed_patterns"]:
+        template += " there are no options allowed"
+    elif not info["allowed_patterns"]:
+        template += " allowed option{plural_allowed} {allowed_values}"
+    elif not info["allowed"]:
+        template += (
+            " allowed are options matching patterns: {allowed_patterns_values}"
+        )
+    else:
+        template += (
+            " allowed option{plural_allowed} {allowed_values}"
+            " and"
+            " options matching patterns: {allowed_patterns_values}"
+        )
+    return template.format(
+        desc=format_optional(info["option_type"], "{0} "),
+        allowed_values=", ".join(sorted(info["allowed"])),
+        allowed_patterns_values=", ".join(sorted(info["allowed_patterns"])),
+        option_names_list=joined_list(info["option_names"]),
+        plural_options=("s:" if len(info["option_names"]) > 1 else ""),
+        plural_allowed=("s are:" if len(info["allowed"]) > 1 else " is"),
+        **info
+    )
+
 def build_node_description(node_types):
     if not node_types:
         return  "Node"
@@ -202,23 +249,7 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
         )
     ,
 
-    codes.INVALID_OPTION: lambda info:
-        (
-            "invalid {desc}option{s} {option_names_list},"
-            +
-            (
-                " allowed option{are} {allowed_values}" if info["allowed"]
-                else " there are no options allowed"
-            )
-        ).format(
-            desc=format_optional(info["option_type"], "{0} "),
-            allowed_values=", ".join(sorted(info["allowed"])),
-            option_names_list=joined_list(info["option_names"]),
-            s=("s:" if len(info["option_names"]) > 1 else ""),
-            are=("s are:" if len(info["allowed"]) > 1 else " is"),
-            **info
-        )
-    ,
+    codes.INVALID_OPTIONS: invalid_options,
 
     codes.INVALID_OPTION_VALUE: lambda info:
         #value on key "allowed_values" is overloaded:
@@ -254,6 +285,18 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
         )
     ,
 
+    codes.INVALID_USERDEFINED_OPTIONS: lambda info:
+        (
+            "invalid {desc}option{plural_options} {option_names_list}, "
+            "{allowed_description}"
+        ).format(
+            desc=format_optional(info["option_type"], "{0} "),
+            option_names_list=joined_list(info["option_names"]),
+            plural_options=("s:" if len(info["option_names"]) > 1 else ""),
+            **info
+        )
+    ,
+
     codes.DEPRECATED_OPTION: lambda info:
         (
             "{desc}option '{option_name}' is deprecated and should not be "
@@ -285,7 +328,12 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
 
     codes.EMPTY_ID: lambda info:
         "{id_description} cannot be empty"
-    .format(**info)
+        .format(**info)
+    ,
+
+    codes.INVALID_CIB_CONTENT: lambda info:
+        "invalid cib: \n{0}"
+        .format(info["report"])
     ,
 
     codes.INVALID_ID: lambda info:
@@ -415,8 +463,10 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
     ,
 
     codes.NODE_COMMUNICATION_ERROR_TIMED_OUT: lambda info:
-        "{node}: Connection timeout ({reason})"
-        .format(**info)
+        (
+            "{node}: Connection timeout, try setting higher timeout in "
+            "--request-timeout option ({reason})"
+        ).format(**info)
     ,
 
     codes.NODE_COMMUNICATION_PROXY_IS_SET:
@@ -441,6 +491,11 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
         )
     ,
 
+    codes.DEFAULTS_CAN_BE_OVERRIDEN:
+        "Defaults do not apply to resources which override them with their "
+        "own defined values"
+    ,
+
     codes.COROSYNC_CONFIG_DISTRIBUTION_STARTED:
         "Sending updated corosync.conf to nodes..."
     ,
@@ -484,6 +539,11 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
         .format(**info)
     ,
 
+    codes.COROSYNC_QUORUM_HEURISTICS_ENABLED_WITH_NO_EXEC:
+        "No exec_NAME options are specified, so heuristics are effectively "
+            "disabled"
+    ,
+
     codes.COROSYNC_CONFIG_RELOADED: "Corosync configuration reloaded",
 
     codes.COROSYNC_CONFIG_RELOAD_ERROR: lambda info:
@@ -677,8 +737,9 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
         .format(**info)
     ,
 
-    codes.CIB_LOAD_ERROR_BAD_FORMAT:
-       "unable to get cib, xml does not conform to the schema"
+    codes.CIB_LOAD_ERROR_BAD_FORMAT: lambda info:
+       "unable to get cib, {reason}"
+       .format(**info)
     ,
 
     codes.CIB_CANNOT_FIND_MANDATORY_SECTION: lambda info:
@@ -691,6 +752,20 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
         .format(**info)
     ,
 
+    codes.CIB_DIFF_ERROR: lambda info:
+        "Unable to diff CIB: {reason}\n{cib_new}"
+        .format(**info)
+    ,
+
+    codes.CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET: lambda info:
+        (
+            "Replacing the whole CIB instead of applying a diff, a race "
+            "condition may happen if the CIB is pushed more than once "
+            "simultaneously. To fix this, upgrade pacemaker to get "
+            "crm_feature_set at least {required_set}, current is {current_set}."
+        ).format(**info)
+    ,
+
     codes.CIB_SAVE_TMP_ERROR: lambda info:
         "Unable to save CIB to a temporary file: {reason}"
         .format(**info)
@@ -731,15 +806,26 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
 
     codes.RESOURCE_CLEANUP_ERROR: lambda info:
         (
-             "Unable to cleanup resource: {resource}\n{reason}"
+             (
+                "Unable to forget failed operations of resource: {resource}"
+                "\n{reason}"
+             )
              if info["resource"] else
-             "Unexpected error occured. 'crm_resource -C' error:\n{reason}"
+             "Unable to forget failed operations of resources\n{reason}"
         ).format(**info)
     ,
 
-    codes.RESOURCE_CLEANUP_TOO_TIME_CONSUMING: lambda info:
+    codes.RESOURCE_REFRESH_ERROR: lambda info:
         (
-             "Cleaning up all resources on all nodes will execute more "
+             "Unable to delete history of resource: {resource}\n{reason}"
+             if info["resource"] else
+             "Unable to delete history of resources\n{reason}"
+        ).format(**info)
+    ,
+
+    codes.RESOURCE_REFRESH_TOO_TIME_CONSUMING: lambda info:
+        (
+             "Deleting history of all resources on all nodes will execute more "
              "than {threshold} operations in the cluster, which may "
              "negatively impact the responsiveness of the cluster. "
              "Consider specifying resource and/or node"
@@ -1293,4 +1379,14 @@ CODE_TO_MESSAGE_BUILDER_MAP = {
             " 'pcs cluster node remove-guest'"
         )
     ,
+
+    codes.TMP_FILE_WRITE: lambda info:
+        (
+            "Writing to a temporary file {file_path}:\n"
+            "--Debug Content Start--\n{content}\n--Debug Content End--\n"
+        ).format(**info)
+    ,
+    codes.UNABLE_TO_PERFORM_OPERATION_ON_ANY_NODE:
+        "Unable to perform operation on any available node/host, therefore it "
+        "is not possible to continue."
 }
