@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 import logging
@@ -23,8 +22,10 @@ from pcs.lib.commands import (
     node,
     qdevice,
     quorum,
+    remote_node,
     resource_agent,
     resource,
+    cib_options,
     stonith,
     sbd,
     stonith_agent,
@@ -45,22 +46,21 @@ def wrapper(dictionary):
 
 def cli_env_to_lib_env(cli_env):
     return LibraryEnvironment(
-        logging.getLogger("old_cli"),
+        logging.getLogger("pcs"),
         LibraryReportProcessorToConsole(cli_env.debug),
         cli_env.user,
         cli_env.groups,
         cli_env.cib_data,
         cli_env.corosync_conf_data,
         booth=cli_env.booth,
-        auth_tokens_getter=cli_env.auth_tokens_getter,
+        token_file_data_getter=cli_env.token_file_data_getter,
         cluster_conf_data=cli_env.cluster_conf_data,
         request_timeout=cli_env.request_timeout,
     )
 
 def lib_env_to_cli_env(lib_env, cli_env):
     if not lib_env.is_cib_live:
-        cli_env.cib_data = lib_env._get_cib_xml()
-        cli_env.cib_upgraded = lib_env.cib_upgraded
+        cli_env.cib_data = lib_env.final_mocked_cib_content
     if not lib_env.is_corosync_conf_live:
         cli_env.corosync_conf_data = lib_env.get_corosync_conf_data()
     if not lib_env.is_cluster_conf_live:
@@ -190,11 +190,23 @@ def load_module(env, middleware_factory, name):
                 middleware_factory.corosync_conf_existing,
             ),
             {
-                "node_add_remote": cluster.node_add_remote,
-                "node_add_guest": cluster.node_add_guest,
-                "node_remove_remote": cluster.node_remove_remote,
-                "node_remove_guest": cluster.node_remove_guest,
                 "node_clear": cluster.node_clear,
+                "verify": cluster.verify,
+            }
+        )
+
+    if name == "remote_node":
+        return bind_all(
+            env,
+            middleware.build(
+                middleware_factory.cib,
+                middleware_factory.corosync_conf_existing,
+            ),
+            {
+                "node_add_remote": remote_node.node_add_remote,
+                "node_add_guest": remote_node.node_add_guest,
+                "node_remove_remote": remote_node.node_remove_remote,
+                "node_remove_guest": remote_node.node_remove_guest,
             }
         )
 
@@ -292,6 +304,7 @@ def load_module(env, middleware_factory, name):
                 "add_device": quorum.add_device,
                 "get_config": quorum.get_config,
                 "remove_device": quorum.remove_device,
+                "remove_device_heuristics": quorum.remove_device_heuristics,
                 "set_expected_votes_live": quorum.set_expected_votes_live,
                 "set_options": quorum.set_options,
                 "status": quorum.status_text,
@@ -335,6 +348,19 @@ def load_module(env, middleware_factory, name):
                 "unmanage": resource.unmanage,
             }
         )
+
+    if name == "cib_options":
+        return bind_all(
+            env,
+            middleware.build(
+                middleware_factory.cib,
+            ),
+            {
+                "set_operations_defaults": cib_options.set_operations_defaults,
+                "set_resources_defaults": cib_options.set_resources_defaults,
+            }
+        )
+
     if name == "stonith":
         return bind_all(
             env,
