@@ -2,13 +2,12 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 from collections import namedtuple
 from functools import partial
 
-from pcs.cli.common import console_report
+from pcs.cli.common.console_report import error
 
 
 def build(*middleware_list):
@@ -20,7 +19,7 @@ def build(*middleware_list):
         return next_in_line(env, *args, **kwargs)
     return run
 
-def cib(use_local_cib, load_cib_content, write_cib):
+def cib(filename, touch_cib_file):
     """
     return configured middleware that cares about local cib
     bool use_local_cib is flag if local cib was required
@@ -28,14 +27,29 @@ def cib(use_local_cib, load_cib_content, write_cib):
     callable write_cib put content of cib to required place
     """
     def apply(next_in_line, env, *args, **kwargs):
-        if use_local_cib:
-            original_content = load_cib_content()
+        if filename:
+            touch_cib_file(filename)
+            try:
+                with open(filename, mode="r") as cib_file:
+                    original_content = cib_file.read()
+            except EnvironmentError as e:
+                raise error(
+                    "Cannot read cib file '{0}': '{1}'"
+                    .format(filename, str(e))
+                )
             env.cib_data = original_content
 
         result_of_next = next_in_line(env, *args, **kwargs)
 
-        if use_local_cib and env.cib_data != original_content:
-            write_cib(env.cib_data, env.cib_upgraded)
+        if filename and env.cib_data != original_content:
+            try:
+                with open(filename, mode="w") as cib_file:
+                    cib_file.write(env.cib_data)
+            except EnvironmentError as e:
+                raise error(
+                    "Cannot write cib file '{0}': '{1}'"
+                    .format(filename, str(e))
+                )
 
         return result_of_next
     return apply
@@ -46,7 +60,7 @@ def corosync_conf_existing(local_file_path):
             try:
                 env.corosync_conf_data = open(local_file_path).read()
             except EnvironmentError as e:
-                raise console_report.error("Unable to read {0}: {1}".format(
+                raise error("Unable to read {0}: {1}".format(
                     local_file_path,
                     e.strerror
                 ))
@@ -59,7 +73,7 @@ def corosync_conf_existing(local_file_path):
                 f.write(env.corosync_conf_data)
                 f.close()
             except EnvironmentError as e:
-                raise console_report.error("Unable to write {0}: {1}".format(
+                raise error("Unable to write {0}: {1}".format(
                     local_file_path,
                     e.strerror
                 ))
@@ -73,7 +87,7 @@ def cluster_conf_read_only(local_file_path):
             try:
                 env.cluster_conf_data = open(local_file_path).read()
             except EnvironmentError as e:
-                raise console_report.error("Unable to read {0}: {1}".format(
+                raise error("Unable to read {0}: {1}".format(
                     local_file_path,
                     e.strerror
                 ))
