@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 from pcs.test.tools.pcs_unittest import TestCase
@@ -37,13 +36,17 @@ class NameBuildTest(TestCase):
     """
     code = None
 
-    def assert_message_from_info(self, message, info):
+    def assert_message_from_info(self, message, info=None):
+        info = info if info else {}
         build = CODE_TO_MESSAGE_BUILDER_MAP[self.code]
-        self.assertEqual(message, build(info))
+        self.assertEqual(
+            message,
+            build(info) if callable(build) else build
+        )
 
 
-class BuildInvalidOptionMessageTest(NameBuildTest):
-    code = codes.INVALID_OPTION
+class BuildInvalidOptionsMessageTest(NameBuildTest):
+    code = codes.INVALID_OPTIONS
     def test_build_message_with_type(self):
         self.assert_message_from_info(
             "invalid TYPE option 'NAME', allowed options are: FIRST, SECOND",
@@ -51,6 +54,7 @@ class BuildInvalidOptionMessageTest(NameBuildTest):
                 "option_names": ["NAME"],
                 "option_type": "TYPE",
                 "allowed": ["SECOND", "FIRST"],
+                "allowed_patterns": [],
             }
         )
 
@@ -61,6 +65,7 @@ class BuildInvalidOptionMessageTest(NameBuildTest):
                 "option_names": ["NAME"],
                 "option_type": "",
                 "allowed": ["FIRST", "SECOND"],
+                "allowed_patterns": [],
             }
         )
 
@@ -71,6 +76,35 @@ class BuildInvalidOptionMessageTest(NameBuildTest):
                 "option_names": ["NAME", "ANOTHER"],
                 "option_type": "",
                 "allowed": ["FIRST"],
+                "allowed_patterns": [],
+            }
+        )
+
+    def test_pattern(self):
+        self.assert_message_from_info(
+            (
+                "invalid option 'NAME', allowed are options matching patterns: "
+                "exec_<name>"
+            ),
+            {
+                "option_names": ["NAME"],
+                "option_type": "",
+                "allowed": [],
+                "allowed_patterns": ["exec_<name>"],
+            }
+        )
+
+    def test_allowed_and_patterns(self):
+        self.assert_message_from_info(
+            (
+                "invalid option 'NAME', allowed option is FIRST and options "
+                "matching patterns: exec_<name>"
+            ),
+            {
+                "option_names": ["NAME"],
+                "option_type": "",
+                "allowed": ["FIRST"],
+                "allowed_patterns": ["exec_<name>"],
             }
         )
 
@@ -81,6 +115,51 @@ class BuildInvalidOptionMessageTest(NameBuildTest):
                 "option_names": ["NAME", "ANOTHER"],
                 "option_type": "",
                 "allowed": [],
+                "allowed_patterns": [],
+            }
+        )
+
+
+class InvalidUserdefinedOptions(NameBuildTest):
+    code = codes.INVALID_USERDEFINED_OPTIONS
+
+    def test_without_type(self):
+        self.assert_message_from_info(
+            (
+                "invalid option 'exec_NAME', "
+                "exec_NAME cannot contain . and whitespace characters"
+            ),
+            {
+                "option_names": ["exec_NAME"],
+                "option_type": "",
+                "allowed_description":
+                    "exec_NAME cannot contain . and whitespace characters"
+                ,
+            }
+        )
+
+    def test_with_type(self):
+        self.assert_message_from_info(
+            (
+                "invalid heuristics option 'exec_NAME', "
+                "exec_NAME cannot contain . and whitespace characters"
+            ),
+            {
+                "option_names": ["exec_NAME"],
+                "option_type": "heuristics",
+                "allowed_description":
+                    "exec_NAME cannot contain . and whitespace characters"
+                ,
+            }
+        )
+
+    def test_more_options(self):
+        self.assert_message_from_info(
+            "invalid TYPE options: 'ANOTHER', 'NAME', DESC",
+            {
+                "option_names": ["NAME", "ANOTHER"],
+                "option_type": "TYPE",
+                "allowed_description": "DESC",
             }
         )
 
@@ -181,6 +260,17 @@ class BuildServiceStartErrorTest(NameBuildTest):
             }
         )
 
+class InvalidCibContent(NameBuildTest):
+    code = codes.INVALID_CIB_CONTENT
+    def test_build_message(self):
+        report = "report\nlines"
+        self.assert_message_from_info(
+            "invalid cib: \n{0}".format(report),
+            {
+                "report": report,
+            }
+        )
+
 class BuildInvalidIdTest(NameBuildTest):
     code = codes.INVALID_ID
     def test_build_message_with_first_char_invalid(self):
@@ -312,6 +402,24 @@ class BuildNodeCommunicationStartedTest(NameBuildTest):
             }
         )
 
+
+class NodeCommunicationErrorTimedOut(NameBuildTest):
+    code = codes.NODE_COMMUNICATION_ERROR_TIMED_OUT
+    def test_success(self):
+        self.assert_message_from_info(
+            (
+                "node-1: Connection timeout, try setting higher timeout in "
+                "--request-timeout option (Connection timed out after 60049 "
+                "milliseconds)"
+            ),
+            {
+                "node": "node-1",
+                "command": "/remote/command",
+                "reason": "Connection timed out after 60049 milliseconds",
+            }
+        )
+
+
 class FormatOptionalTest(TestCase):
     def test_info_key_is_falsy(self):
         self.assertEqual("", format_optional("", "{0}: "))
@@ -570,18 +678,24 @@ class ResourceOperationIntevalAdaptedTest(NameBuildTest):
 class IdBelongsToUnexpectedType(NameBuildTest):
     code = codes.ID_BELONGS_TO_UNEXPECTED_TYPE
     def test_build_message_with_data(self):
-        self.assert_message_from_info("'ID' is not primitive/master/clone", {
-            "id": "ID",
-            "expected_types": ["primitive", "master", "clone"],
-            "current_type": "op",
-        })
+        self.assert_message_from_info(
+            "'ID' is not a clone/master/resource",
+            {
+                "id": "ID",
+                "expected_types": ["primitive", "master", "clone"],
+                "current_type": "op",
+            }
+        )
 
-    def test_build_message_with_transformation(self):
-        self.assert_message_from_info("'ID' is not a group", {
-            "id": "ID",
-            "expected_types": ["group"],
-            "current_type": "op",
-        })
+    def test_build_message_with_transformation_and_article(self):
+        self.assert_message_from_info(
+            "'ID' is not an ACL group/ACL user",
+            {
+                "id": "ID",
+                "expected_types": ["acl_target", "acl_group"],
+                "current_type": "op",
+            }
+        )
 
 class ResourceRunOnNodes(NameBuildTest):
     code = codes.RESOURCE_RUNNING_ON_NODES
@@ -1737,3 +1851,233 @@ class ServiceDisableSuccess(NameBuildTest):
                 "instance": "an_instance",
             }
         )
+
+
+class CibDiffError(NameBuildTest):
+    code = codes.CIB_DIFF_ERROR
+    def test_success(self):
+        self.assert_message_from_info(
+            "Unable to diff CIB: error message\n<cib-new />",
+            {
+                "reason": "error message",
+                "cib_old": "<cib-old />",
+                "cib_new": "<cib-new />",
+            }
+        )
+
+
+class TmpFileWrite(NameBuildTest):
+    code = codes.TMP_FILE_WRITE
+    def test_success(self):
+        self.assert_message_from_info(
+            (
+                "Writing to a temporary file /tmp/pcs/test.tmp:\n"
+                "--Debug Content Start--\n"
+                "test file\ncontent\n\n"
+                "--Debug Content End--\n"
+            ),
+            {
+                "file_path": "/tmp/pcs/test.tmp",
+                "content": "test file\ncontent\n",
+            }
+        )
+
+
+class DefaultsCanBeOverriden(NameBuildTest):
+    code = codes.DEFAULTS_CAN_BE_OVERRIDEN
+    def test_message(self):
+        self.assert_message_from_info(
+            "Defaults do not apply to resources which override them with their "
+            "own defined values"
+        )
+
+
+class CibLoadErrorBadFormat(NameBuildTest):
+    code = codes.CIB_LOAD_ERROR_BAD_FORMAT
+    def test_message(self):
+        self.assert_message_from_info(
+            "unable to get cib, something wrong",
+            {
+                "reason": "something wrong"
+            }
+        )
+
+
+class CorosyncQuorumHeuristicsEnabledWithNoExec(NameBuildTest):
+    code = codes.COROSYNC_QUORUM_HEURISTICS_ENABLED_WITH_NO_EXEC
+    def test_message(self):
+        self.assert_message_from_info(
+            "No exec_NAME options are specified, so heuristics are effectively "
+                "disabled"
+        )
+
+
+class ResourceCleanupError(NameBuildTest):
+    code = codes.RESOURCE_CLEANUP_ERROR
+
+    def test_minimal(self):
+        self.assert_message_from_info(
+            "Unable to forget failed operations of resources\nsomething wrong",
+            {
+                "reason": "something wrong",
+                "resource": None,
+                "node": None,
+            }
+        )
+
+    def test_node(self):
+        self.assert_message_from_info(
+            "Unable to forget failed operations of resources\nsomething wrong",
+            {
+                "reason": "something wrong",
+                "resource": None,
+                "node": "N1",
+            }
+        )
+
+    def test_resource(self):
+        self.assert_message_from_info(
+            "Unable to forget failed operations of resource: R1\n"
+                "something wrong"
+            ,
+            {
+                "reason": "something wrong",
+                "resource": "R1",
+                "node": None,
+            }
+        )
+
+    def test_resource_and_node(self):
+        self.assert_message_from_info(
+            "Unable to forget failed operations of resource: R1\n"
+                "something wrong"
+            ,
+            {
+                "reason": "something wrong",
+                "resource": "R1",
+                "node": "N1",
+            }
+        )
+
+
+class ResourceRefreshError(NameBuildTest):
+    code = codes.RESOURCE_REFRESH_ERROR
+
+    def test_minimal(self):
+        self.assert_message_from_info(
+            "Unable to delete history of resources\nsomething wrong",
+            {
+                "reason": "something wrong",
+                "resource": None,
+                "node": None,
+            }
+        )
+
+    def test_node(self):
+        self.assert_message_from_info(
+            "Unable to delete history of resources\nsomething wrong",
+            {
+                "reason": "something wrong",
+                "resource": None,
+                "node": "N1",
+            }
+        )
+
+    def test_resource(self):
+        self.assert_message_from_info(
+            "Unable to delete history of resource: R1\nsomething wrong",
+            {
+                "reason": "something wrong",
+                "resource": "R1",
+                "node": None,
+            }
+        )
+
+    def test_resource_and_node(self):
+        self.assert_message_from_info(
+            "Unable to delete history of resource: R1\nsomething wrong",
+            {
+                "reason": "something wrong",
+                "resource": "R1",
+                "node": "N1",
+            }
+        )
+
+
+class ResourceRefreshTooTimeConsuming(NameBuildTest):
+    code = codes.RESOURCE_REFRESH_TOO_TIME_CONSUMING
+    def test_success(self):
+        self.assert_message_from_info(
+            "Deleting history of all resources on all nodes will execute more "
+                "than 25 operations in the cluster, which may negatively "
+                "impact the responsiveness of the cluster. Consider specifying "
+                "resource and/or node"
+            ,
+            {
+                "threshold": 25,
+            }
+        )
+
+
+class IdNotFound(NameBuildTest):
+    code = codes.ID_NOT_FOUND
+    def test_id(self):
+        self.assert_message_from_info(
+            "'ID' does not exist",
+            {
+                "id": "ID",
+                "expected_types": [],
+                "context_type": "",
+                "context_id": "",
+            }
+        )
+
+    def test_id_and_type(self):
+        self.assert_message_from_info(
+            "clone/master/resource 'ID' does not exist",
+            {
+                "id": "ID",
+                "expected_types": ["primitive", "master", "clone"],
+                "context_type": "",
+                "context_id": "",
+            }
+        )
+
+    def test_context(self):
+        self.assert_message_from_info(
+            "there is no 'ID' in the C_TYPE 'C_ID'",
+            {
+                "id": "ID",
+                "expected_types": [],
+                "context_type": "C_TYPE",
+                "context_id": "C_ID",
+            }
+        )
+
+    def test_type_and_context(self):
+        self.assert_message_from_info(
+            "there is no ACL user 'ID' in the C_TYPE 'C_ID'",
+            {
+                "id": "ID",
+                "expected_types": ["acl_target"],
+                "context_type": "C_TYPE",
+                "context_id": "C_ID",
+            }
+        )
+
+
+class CibPushForcedFullDueToCrmFeatureSet(NameBuildTest):
+    code = codes.CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET
+    def test_success(self):
+        self.assert_message_from_info(
+            (
+                "Replacing the whole CIB instead of applying a diff, a race "
+                "condition may happen if the CIB is pushed more than once "
+                "simultaneously. To fix this, upgrade pacemaker to get "
+                "crm_feature_set at least 3.0.9, current is 3.0.6."
+            ),
+            {
+                "required_set": "3.0.9",
+                "current_set": "3.0.6",
+            }
+        )
