@@ -2,9 +2,9 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
+import math
 import os
 import subprocess
 import re
@@ -22,6 +22,13 @@ except ImportError:
     # python3
     from subprocess import getstatusoutput
 
+try:
+    # python2
+    from urlparse import urlparse
+except ImportError:
+    # python3
+    from urllib.parse import urlparse
+
 from pcs import (
     constraint,
     node,
@@ -46,8 +53,17 @@ from pcs.lib import (
     reports as lib_reports,
 )
 from pcs.lib.booth import sync as booth_sync
-from pcs.lib.commands.cluster import _share_authkey, _destroy_pcmk_remote_env
+from pcs.lib.commands.remote_node import _share_authkey, _destroy_pcmk_remote_env
 from pcs.lib.commands.quorum import _add_device_model_net
+from pcs.lib.communication.corosync import CheckCorosyncOffline
+from pcs.lib.communication.nodes import DistributeFiles
+from pcs.lib.communication.sbd import (
+    CheckSbd,
+    SetSbdConfig,
+    EnableSbdService,
+    DisableSbdService,
+)
+from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.corosync import (
     config_parser as corosync_conf_utils,
     qdevice_net,
@@ -66,8 +82,7 @@ from pcs.lib.external import (
     node_communicator_exception_to_report_item,
 )
 from pcs.lib.env_tools import get_nodes
-from pcs.lib.node import NodeAddresses, NodeAddressesList
-from pcs.lib.nodes_task import check_corosync_offline_on_nodes, distribute_files
+from pcs.lib.node import NodeAddresses
 from pcs.lib import node_communication_format
 import pcs.lib.pacemaker.live as lib_pacemaker
 from pcs.lib.tools import (
@@ -126,7 +141,7 @@ def cluster_cmd(argv):
             node.node_standby_cmd(
                 utils.get_library_wrapper(),
                 argv,
-                utils.get_modificators(),
+                utils.get_modifiers(),
                 True
             )
         except LibraryError as e:
@@ -138,7 +153,7 @@ def cluster_cmd(argv):
             node.node_standby_cmd(
                 utils.get_library_wrapper(),
                 argv,
-                utils.get_modificators(),
+                utils.get_modifiers(),
                 False
             )
         except LibraryError as e:
@@ -191,10 +206,10 @@ def cluster_cmd(argv):
                 remote_node_command_map[argv[0]](
                     utils.get_library_wrapper(),
                     argv[1:],
-                    utils.get_modificators()
+                    utils.get_modifiers()
                 )
             except LibraryError as e:
-                utils.process_library_reports(e.args)
+                process_library_reports(e.args)
             except CmdLineInputError as e:
                 utils.exit_on_cmdline_input_errror(
                     e, "cluster", "node " + argv[0]
@@ -262,10 +277,10 @@ def auth_nodes(nodes):
     else:
         password = None
 
-    set_nodes = set(nodes)
+    nodes_dict = parse_nodes_with_ports(nodes)
     need_auth = "--force" in utils.pcs_options or (username or password)
     if not need_auth:
-        for node in set_nodes:
+        for node in nodes_dict.keys():
             status = utils.checkAuthorization(node)
             if status[0] == 3:
                 need_auth = True
@@ -275,7 +290,9 @@ def auth_nodes(nodes):
                 try:
                     auth_status = json.loads(status[1])
                     if auth_status["success"]:
-                        if set_nodes.issubset(set(auth_status["node_list"])):
+                        if set(nodes_dict.keys()).issubset(
+                            set(auth_status["node_list"])
+                        ):
                             mutually_authorized = True
                 except (ValueError, KeyError):
                     pass
@@ -290,19 +307,38 @@ def auth_nodes(nodes):
             password = utils.get_terminal_password()
 
         utils.auth_nodes_do(
-            set_nodes, username, password, '--force' in utils.pcs_options,
+            nodes_dict, username, password, '--force' in utils.pcs_options,
             '--local' in utils.pcs_options
         )
     else:
-        for node in set_nodes:
+        for node in nodes_dict.keys():
             print(node + ": Already authorized")
 
+
+def parse_nodes_with_ports(node_list):
+    result = {}
+    for node in node_list:
+        if node.count(":") > 1 and not node.startswith("["):
+            # if IPv6 without port put it in parentheses
+            node = "[{0}]".format(node)
+        # adding protocol so urlparse will parse hostname/ip and port correctly
+        url = urlparse("http://{0}".format(node))
+        if url.hostname in result and result[url.hostname] != url.port:
+            raise CmdLineInputError(
+                "Node '{0}' defined twice with different ports".format(
+                    url.hostname
+                )
+            )
+        result[url.hostname] = url.port
+    return result
+
+
 def cluster_certkey(argv):
     return pcsd.pcsd_certkey(argv)
 
 
 def cluster_setup(argv):
-    modifiers = utils.get_modificators()
+    modifiers = utils.get_modifiers()
     allowed_encryption_values = ["0", "1"]
     if modifiers["encryption"] not in allowed_encryption_values:
         process_library_reports([
@@ -380,7 +416,8 @@ def cluster_setup(argv):
         )
     if udpu_rrp and "rrp_mode" not in options["transport_options"]:
         options["transport_options"]["rrp_mode"] = "passive"
-    process_library_reports(messages)
+    if messages:
+        process_library_reports(messages)
 
     # prepare config file
     if is_rhel6:
@@ -399,7 +436,8 @@ def cluster_setup(argv):
             options["quorum_options"],
             modifiers["encryption"] == "1"
         )
-    process_library_reports(messages)
+    if messages:
+        process_library_reports(messages)
 
     # setup on the local node
     if "--local" in utils.pcs_options:
@@ -447,8 +485,10 @@ def cluster_setup(argv):
             all_nodes_available = True
             for node in primary_addr_list:
                 available, message = utils.canAddNodeToCluster(
-                    lib_env.node_communicator(),
-                    NodeAddresses(node)
+                    lib_env.get_node_communicator(),
+                    lib_env.get_node_target_factory().get_target(
+                        NodeAddresses(node)
+                    )
                 )
                 if not available:
                     all_nodes_available = False
@@ -475,17 +515,18 @@ def cluster_setup(argv):
                         generate_binary_key(random_bytes_count=128)
                     )
                 )
-
-            distribute_files(
-                lib_env.node_communicator(),
+            com_cmd = DistributeFiles(
                 lib_env.report_processor,
                 file_definitions,
-                NodeAddressesList(
-                    [NodeAddresses(node) for node in primary_addr_list]
-                ),
-                skip_offline_nodes=modifiers["skip_offline_nodes"],
-                allow_incomplete_distribution="--force" in utils.pcs_options
+                skip_offline_targets=modifiers["skip_offline_nodes"],
+                allow_fails=modifiers["force"],
             )
+            com_cmd.set_targets(
+                lib_env.get_node_target_factory().get_target_list(
+                    [NodeAddresses(node) for node in primary_addr_list]
+                )
+            )
+            run_and_raise(lib_env.get_node_communicator(), com_cmd)
         except LibraryError as e: #Theoretically, this should not happen
             utils.process_library_reports(e.args)
 
@@ -991,9 +1032,10 @@ def start_cluster(argv):
         wait = True
 
     if len(argv) > 0:
-        start_cluster_nodes(argv)
+        nodes = set(argv) # unique
+        start_cluster_nodes(nodes)
         if wait:
-            wait_for_nodes_started(argv, wait_timeout)
+            wait_for_nodes_started(nodes, wait_timeout)
         return
 
     print("Starting Cluster...")
@@ -1036,7 +1078,20 @@ def start_cluster_all():
         wait_for_nodes_started(all_nodes, wait_timeout)
 
 def start_cluster_nodes(nodes):
-    node_errors = parallel_for_nodes(utils.startCluster, nodes, quiet=True)
+    # Large clusters take longer time to start up. So we make the timeout longer
+    # for each 8 nodes:
+    #  1 -  8 nodes: 1 * timeout
+    #  9 - 16 nodes: 2 * timeout
+    # 17 - 24 nodes: 3 * timeout
+    # and so on
+    # Users can override this and set their own timeout by specifying
+    # the --request-timeout option (see utils.sendHTTPRequest).
+    timeout = int(
+        settings.default_request_timeout * math.ceil(len(nodes) / 8.0)
+    )
+    node_errors = parallel_for_nodes(
+        utils.startCluster, nodes, quiet=True, timeout=timeout
+    )
     if node_errors:
         utils.err(
             "unable to start all nodes\n" + "\n".join(node_errors.values())
@@ -1404,7 +1459,7 @@ def cluster_push(argv):
             "--no-version"
         ]
         patch, error, dummy_retval = runner.run(command)
-        # dummy_retval == -1 means one of two things:
+        # dummy_retval == 1 means one of two things:
         # a) an error has occured
         # b) --original and --new differ
         # therefore it's of no use to see if an error occurred
@@ -1552,12 +1607,15 @@ def _ensure_cluster_is_offline_if_atb_should_be_enabled(
                 "make SBD fencing effecive after this change. Cluster has to "
                 "be offline to be able to make this change."
             )
-            check_corosync_offline_on_nodes(
-                lib_env.node_communicator(),
-                lib_env.report_processor,
-                corosync_conf.get_nodes(),
-                skip_offline_nodes
+            com_cmd = CheckCorosyncOffline(
+                lib_env.report_processor, skip_offline_nodes
             )
+            com_cmd.set_targets(
+                lib_env.get_node_target_factory().get_target_list(
+                    corosync_conf.get_nodes()
+                )
+            )
+            run_and_raise(lib_env.get_node_communicator(), com_cmd)
 
 
 def cluster_node(argv):
@@ -1574,7 +1632,7 @@ def cluster_node(argv):
             node_add_outside_cluster(
                 utils.get_library_wrapper(),
                 argv[1:],
-                utils.get_modificators(),
+                utils.get_modifiers(),
             )
         except CmdLineInputError as e:
             utils.exit_on_cmdline_input_errror(e, "cluster", "node")
@@ -1610,7 +1668,7 @@ def cluster_node(argv):
             utils.err(msg)
 
     lib_env = utils.get_lib_env()
-    modifiers = utils.get_modificators()
+    modifiers = utils.get_modifiers()
 
     if add_node == True:
         node_add(lib_env, node0, node1, modifiers)
@@ -1672,13 +1730,16 @@ def node_add(lib_env, node0, node1, modifiers):
             "you must not specify ring 1 address for the node"
         )
     node_addr = NodeAddresses(node0, node1)
-    node_communicator = lib_env.node_communicator()
-    (canAdd, error) =  utils.canAddNodeToCluster(node_communicator, node_addr)
+    (canAdd, error) =  utils.canAddNodeToCluster(
+        lib_env.get_node_communicator(),
+        lib_env.get_node_target_factory().get_target(node_addr)
+    )
 
     if not canAdd:
         utils.err("Unable to add '%s' to cluster: %s" % (node0, error))
 
     report_processor = lib_env.report_processor
+    com_factory = lib_env.communicator_factory
 
     # First set up everything else than corosync. Once the new node is
     # present in corosync.conf / cluster.conf, it's considered part of a
@@ -1691,7 +1752,7 @@ def node_add(lib_env, node0, node1, modifiers):
             conf_facade = corosync_conf_facade.from_string(
                 utils.getCorosyncConf()
             )
-            qdevice_model, qdevice_model_options, _ = conf_facade.get_quorum_device_settings()
+            qdevice_model, qdevice_model_options, _, _ = conf_facade.get_quorum_device_settings()
             if qdevice_model == "net":
                 _add_device_model_net(
                     lib_env,
@@ -1702,6 +1763,9 @@ def node_add(lib_env, node0, node1, modifiers):
                 )
 
         # sbd setup
+        new_node_target = lib_env.get_node_target_factory().get_target(
+            node_addr
+        )
         if lib_sbd.is_sbd_enabled(utils.cmd_runner()):
             if "--watchdog" not in utils.pcs_options:
                 watchdog = settings.sbd_watchdog_default
@@ -1736,50 +1800,51 @@ def node_add(lib_env, node0, node1, modifiers):
                     "therefore --device should not be specified"
                 )
 
-            lib_sbd.check_sbd_on_node(
-                report_processor, node_communicator, node_addr, watchdog,
-                device_list
-            )
+            com_cmd = CheckSbd(lib_env.report_processor)
+            com_cmd.add_request(new_node_target, watchdog, device_list)
+            run_and_raise(com_factory.get_communicator(), com_cmd)
 
-            report_processor.process(
-                lib_reports.sbd_config_distribution_started()
-            )
-            lib_sbd.set_sbd_config_on_node(
-                report_processor,
-                node_communicator,
-                node_addr,
-                sbd_cfg,
-                watchdog,
-                device_list,
-            )
-            report_processor.process(lib_reports.sbd_enabling_started())
-            lib_sbd.enable_sbd_service_on_node(
-                report_processor, node_communicator, node_addr
+            com_cmd = SetSbdConfig(lib_env.report_processor)
+            com_cmd.add_request(
+                new_node_target,
+                lib_sbd.create_sbd_config(
+                    sbd_cfg, new_node_target.label, watchdog, device_list
+                )
             )
+            run_and_raise(com_factory.get_communicator(), com_cmd)
+
+            com_cmd = EnableSbdService(lib_env.report_processor)
+            com_cmd.add_request(new_node_target)
+            run_and_raise(com_factory.get_communicator(), com_cmd)
         else:
-            report_processor.process(lib_reports.sbd_disabling_started())
-            lib_sbd.disable_sbd_service_on_node(
-                report_processor, node_communicator, node_addr
-            )
+            com_cmd = DisableSbdService(lib_env.report_processor)
+            com_cmd.add_request(new_node_target)
+            run_and_raise(com_factory.get_communicator(), com_cmd)
 
         # booth setup
         booth_sync.send_all_config_to_node(
-            node_communicator,
+            com_factory.get_communicator(),
             report_processor,
-            node_addr,
+            new_node_target,
             rewrite_existing=modifiers["force"],
             skip_wrong_config=modifiers["force"]
         )
 
         if os.path.isfile(settings.corosync_authkey_file):
-            distribute_files(
-                lib_env.node_communicator(),
+            com_cmd = DistributeFiles(
                 lib_env.report_processor,
                 node_communication_format.corosync_authkey_file(
-                    open(settings.corosync_authkey_file).read()
+                    open(settings.corosync_authkey_file, "rb").read()
                 ),
-                NodeAddressesList([node_addr]),
+                # added force, it was missing before
+                # but it doesn't make sence here
+                skip_offline_targets=modifiers["skip_offline_nodes"],
+                allow_fails=modifiers["force"],
             )
+            com_cmd.set_targets(
+                lib_env.get_node_target_factory().get_target_list([node_addr])
+            )
+            run_and_raise(lib_env.get_node_communicator(), com_cmd)
 
         # do not send pcmk authkey to guest and remote nodes, they either have
         # it or are not working anyway
@@ -1816,14 +1881,14 @@ def node_add(lib_env, node0, node1, modifiers):
         # 1. add the new node to corosync.conf
         # 2. reload  corosync.conf before the new node is started
         # 3. start the new node
-        # If done otherwise, membership gets broken a qdevice hangs. Cluster
+        # If done otherwise, membership gets broken and qdevice hangs. Cluster
         # will recover after a minute or so but still it's a wrong way.
         # When corosync 1 is in use, the procedure for adding a node is:
         # 1. add the new node to cluster.conf
         # 2. start the new node
         # Starting the node will automaticall reload cluster.conf on all
         # nodes. If the config is reloaded before the new node is started,
-        # the new node gets fenced by the cluster,
+        # the new node gets fenced by the cluster.
         output, retval = utils.reloadCorosync()
     if corosync_conf != None:
         # send local cluster pcsd configs to the new node
@@ -2204,33 +2269,30 @@ def cluster_destroy(argv):
             pass
 
 def cluster_verify(argv):
-    nofilename = True
-    if len(argv) == 1:
-        filename = argv.pop(0)
-        nofilename = False
-    elif len(argv) > 1:
+    if len(argv) > 1:
         usage.cluster("verify")
+        raise SystemExit(1)
 
-    options = []
-    if "-V" in utils.pcs_options:
-        options.append("-V")
-    if nofilename:
-        options.append("--live-check")
-    else:
-        options.append("--xml-file")
-        options.append(filename)
-    output, retval = utils.run([settings.crm_verify] + options)
-    if output != "":
-        print(output)
+    if argv:
+        filename = argv[0]
+        if not utils.usefile:
+            #We must operate on given cib everywhere.
+            utils.usefile = True
+            utils.filename = filename
+        elif os.path.abspath(filename) == os.path.abspath(utils.filename):
+            warn("File '{0}' specified twice".format(os.path.abspath(filename)))
+        else:
+            raise error(
+                "Ambiguous cib filename specification: '{0}' vs  -f '{1}'"
+                .format(filename, utils.filename)
+            )
 
     lib = utils.get_library_wrapper()
     try:
-        lib.fencing_topology.verify()
+        lib.cluster.verify(verbose="-V" in utils.pcs_options)
     except LibraryError as e:
         utils.process_library_reports(e.args)
 
-    return retval
-
 def cluster_report(argv):
     if len(argv) != 1:
         usage.cluster(["report"])
@@ -2260,6 +2322,12 @@ def cluster_report(argv):
 
     crm_report_opts.append(outfile)
     output, retval = utils.run([settings.crm_report] + crm_report_opts)
+    if (
+        retval != 0
+        and
+        "ERROR: Cannot determine nodes; specify --nodes or --single-node" in output
+    ):
+        utils.err("cluster is not configured on this node")
     newoutput = ""
     for line in output.split("\n"):
         if line.startswith("cat:") or line.startswith("grep") or line.startswith("grep") or line.startswith("tail"):
@@ -2272,6 +2340,8 @@ def cluster_report(argv):
             continue
         if "to diagnose" in line:
             continue
+        if "--dest" in line:
+            line = line.replace("--dest", "<dest>")
         newoutput = newoutput + line + "\n"
     if retval != 0:
         utils.err(newoutput)
