@@ -71,6 +71,7 @@ CIB_FENCING_LEVEL_DOES_NOT_EXIST = "CIB_FENCING_LEVEL_DOES_NOT_EXIST"
 CIB_LOAD_ERROR_BAD_FORMAT = "CIB_LOAD_ERROR_BAD_FORMAT"
 CIB_LOAD_ERROR = "CIB_LOAD_ERROR"
 CIB_LOAD_ERROR_SCOPE_MISSING = "CIB_LOAD_ERROR_SCOPE_MISSING"
+CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET = "CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET"
 CIB_PUSH_ERROR = "CIB_PUSH_ERROR"
 CIB_SAVE_TMP_ERROR = "CIB_SAVE_TMP_ERROR"
 CIB_UPGRADE_FAILED = "CIB_UPGRADE_FAILED"
@@ -121,7 +122,7 @@ ID_NOT_FOUND = 'ID_NOT_FOUND'
 IGNORED_CMAN_UNSUPPORTED_OPTION = 'IGNORED_CMAN_UNSUPPORTED_OPTION'
 INVALID_CIB_CONTENT = "INVALID_CIB_CONTENT"
 INVALID_ID = "INVALID_ID"
-INVALID_OPTION = "INVALID_OPTION"
+INVALID_OPTIONS = "INVALID_OPTIONS"
 INVALID_USERDEFINED_OPTIONS = "INVALID_USERDEFINED_OPTIONS"
 INVALID_OPTION_TYPE = "INVALID_OPTION_TYPE"
 INVALID_OPTION_VALUE = "INVALID_OPTION_VALUE"
@@ -249,6 +250,7 @@ UNABLE_TO_GET_AGENT_METADATA = 'UNABLE_TO_GET_AGENT_METADATA'
 UNABLE_TO_READ_COROSYNC_CONFIG = "UNABLE_TO_READ_COROSYNC_CONFIG"
 UNABLE_TO_GET_SBD_CONFIG = "UNABLE_TO_GET_SBD_CONFIG"
 UNABLE_TO_GET_SBD_STATUS = "UNABLE_TO_GET_SBD_STATUS"
+UNABLE_TO_PERFORM_OPERATION_ON_ANY_NODE = "UNABLE_TO_PERFORM_OPERATION_ON_ANY_NODE"
 UNKNOWN_COMMAND = 'UNKNOWN_COMMAND'
 WATCHDOG_INVALID = "WATCHDOG_INVALID"
 UNSUPPORTED_OPERATION_ON_NON_SYSTEMD_SYSTEMS = "UNSUPPORTED_OPERATION_ON_NON_SYSTEMD_SYSTEMS"
