@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 from lxml import etree
@@ -23,6 +22,7 @@ from pcs.lib.pacemaker.values import sanitize_id
 from pcs.lib.xml_tools import (
     get_sub_element,
     update_attributes_remove_empty,
+    remove_when_pointless,
 )
 
 TAG = "bundle"
@@ -267,9 +267,8 @@ def update(
 
     # remove empty elements with no attributes
     # meta attributes are handled in their own function
-    for element in (network_element, storage_element):
-        if len(element) < 1 and not element.attrib:
-            element.getparent().remove(element)
+    remove_when_pointless(network_element)
+    remove_when_pointless(storage_element)
 
 def add_resource(bundle_element, primitive_element):
     """
@@ -465,7 +464,7 @@ def _validate_map_ids_exist(bundle_el, map_type, map_label, id_list):
     for id in id_list:
         try:
             find_element_by_tag_and_id(
-                map_type, bundle_el, id, id_description=map_label
+                map_type, bundle_el, id, id_types=[map_label]
             )
         except LibraryError as e:
             report_list.extend(e.args)
