@@ -69,7 +69,7 @@ class PrepareOptionsPlainTest(TestCase):
             ),
             (
                 severities.ERROR,
-                report_codes.INVALID_OPTION,
+                report_codes.INVALID_OPTIONS,
                 {
                     "option_names": ["unknown"],
                     "option_type": None,
