@@ -2,15 +2,15 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
+from pcs.common.tools import Version
 from pcs.lib import reports
 from pcs.lib.cib import alert
 from pcs.lib.errors import LibraryError
 
 
-REQUIRED_CIB_VERSION = (2, 5, 0)
+REQUIRED_CIB_VERSION = Version(2, 5, 0)
 
 
 def create_alert(
@@ -33,15 +33,19 @@ def create_alert(
     description -- alert description description
     """
     if not path:
-        raise LibraryError(reports.required_option_is_missing("path"))
+        raise LibraryError(reports.required_option_is_missing(["path"]))
 
-    cib = lib_env.get_cib(REQUIRED_CIB_VERSION)
 
-    alert_el = alert.create_alert(cib, alert_id, path, description)
+    alert_el = alert.create_alert(
+        lib_env.get_cib(REQUIRED_CIB_VERSION),
+        alert_id,
+        path,
+        description
+    )
     alert.update_instance_attributes(alert_el, instance_attribute_dict)
     alert.update_meta_attributes(alert_el, meta_attribute_dict)
 
-    lib_env.push_cib(cib)
+    lib_env.push_cib()
 
 
 def update_alert(
@@ -63,13 +67,17 @@ def update_alert(
     description -- new description, if empty string, old description will be
         deleted, if None old value will stay unchanged
     """
-    cib = lib_env.get_cib(REQUIRED_CIB_VERSION)
 
-    alert_el = alert.update_alert(cib, alert_id, path, description)
+    alert_el = alert.update_alert(
+        lib_env.get_cib(REQUIRED_CIB_VERSION),
+        alert_id,
+        path,
+        description
+    )
     alert.update_instance_attributes(alert_el, instance_attribute_dict)
     alert.update_meta_attributes(alert_el, meta_attribute_dict)
 
-    lib_env.push_cib(cib)
+    lib_env.push_cib()
 
 
 def remove_alert(lib_env, alert_id_list):
@@ -86,8 +94,9 @@ def remove_alert(lib_env, alert_id_list):
             alert.remove_alert(cib, alert_id)
         except LibraryError as e:
             report_list += e.args
+
     lib_env.report_processor.process_list(report_list)
-    lib_env.push_cib(cib)
+    lib_env.push_cib()
 
 
 def add_recipient(
@@ -114,13 +123,12 @@ def add_recipient(
     """
     if not recipient_value:
         raise LibraryError(
-            reports.required_option_is_missing("value")
+            reports.required_option_is_missing(["value"])
         )
 
-    cib = lib_env.get_cib(REQUIRED_CIB_VERSION)
     recipient = alert.add_recipient(
         lib_env.report_processor,
-        cib,
+        lib_env.get_cib(REQUIRED_CIB_VERSION),
         alert_id,
         recipient_value,
         recipient_id=recipient_id,
@@ -130,7 +138,7 @@ def add_recipient(
     alert.update_instance_attributes(recipient, instance_attribute_dict)
     alert.update_meta_attributes(recipient, meta_attribute_dict)
 
-    lib_env.push_cib(cib)
+    lib_env.push_cib()
 
 
 def update_recipient(
@@ -159,10 +167,9 @@ def update_recipient(
         raise LibraryError(
             reports.cib_alert_recipient_invalid_value(recipient_value)
         )
-    cib = lib_env.get_cib(REQUIRED_CIB_VERSION)
     recipient = alert.update_recipient(
         lib_env.report_processor,
-        cib,
+        lib_env.get_cib(REQUIRED_CIB_VERSION),
         recipient_id,
         recipient_value=recipient_value,
         description=description,
@@ -171,7 +178,7 @@ def update_recipient(
     alert.update_instance_attributes(recipient, instance_attribute_dict)
     alert.update_meta_attributes(recipient, meta_attribute_dict)
 
-    lib_env.push_cib(cib)
+    lib_env.push_cib()
 
 
 def remove_recipient(lib_env, recipient_id_list):
@@ -189,7 +196,7 @@ def remove_recipient(lib_env, recipient_id_list):
         except LibraryError as e:
             report_list += e.args
     lib_env.report_processor.process_list(report_list)
-    lib_env.push_cib(cib)
+    lib_env.push_cib()
 
 
 def get_all_alerts(lib_env):
