@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 import base64
@@ -20,13 +19,16 @@ from pcs.lib.booth import (
     reports as booth_reports,
     resource,
     status,
-    sync,
 )
 from pcs.lib.booth.config_parser import parse, build
 from pcs.lib.booth.env import get_config_file_name
 from pcs.lib.cib.tools import get_resources
+from pcs.lib.communication.booth import (
+    BoothGetConfig,
+    BoothSendConfig,
+)
+from pcs.lib.communication.tools import run_and_raise
 from pcs.lib.errors import LibraryError, ReportItemSeverity
-from pcs.lib.node import NodeAddresses
 from pcs.lib.resource_agent import find_valid_resource_agent_by_name
 
 
@@ -112,9 +114,11 @@ def config_text(env, name, node_name=None):
         # TODO add name support
         return env.booth.get_config_content()
 
-    remote_data = sync.pull_config_from_node(
-        env.node_communicator(), NodeAddresses(node_name), name
-    )
+    com_cmd = BoothGetConfig(env.report_processor, name)
+    com_cmd.set_targets([
+        env.get_node_target_factory().get_target_from_hostname(node_name)
+    ])
+    remote_data = run_and_raise(env.get_node_communicator(), com_cmd)[0][1]
     try:
         return remote_data["config"]["data"]
     except KeyError:
@@ -157,8 +161,7 @@ def create_in_cluster(env, name, ip, allow_absent_resource_agent=False):
     bool allow_absent_resource_agent is flag allowing create booth resource even
         if its agent is not installed
     """
-    cib = env.get_cib()
-    resources_section = get_resources(cib)
+    resources_section = get_resources(env.get_cib())
 
     booth_config_file_path = get_config_file_name(name)
     if resource.find_for_config(resources_section, booth_config_file_path):
@@ -196,7 +199,7 @@ def create_in_cluster(env, name, ip, allow_absent_resource_agent=False):
         instance_attributes={"config": booth_config_file_path},
     ))
 
-    env.push_cib(cib)
+    env.push_cib()
 
 def remove_from_cluster(env, name, resource_remove, allow_remove_multiple):
     #TODO resource_remove is provisional hack until resources are not moved to
@@ -257,17 +260,20 @@ def config_sync(env, name, skip_offline_nodes=False):
     authfile_content = config_files.read_authfile(
         env.report_processor, authfile_path
     )
-
-    sync.send_config_to_all_nodes(
-        env.node_communicator(),
+    com_cmd = BoothSendConfig(
         env.report_processor,
-        env.get_corosync_conf().get_nodes(),
         name,
         config,
         authfile=authfile_path,
         authfile_data=authfile_content,
-        skip_offline=skip_offline_nodes
+        skip_offline_targets=skip_offline_nodes
     )
+    com_cmd.set_targets(
+        env.get_node_target_factory().get_target_list(
+            env.get_corosync_conf().get_nodes()
+        )
+    )
+    run_and_raise(env.get_node_communicator(), com_cmd)
 
 
 def enable_booth(env, name=None):
@@ -363,9 +369,11 @@ def pull_config(env, node_name, name):
     env.report_processor.process(
         booth_reports.booth_fetching_config_from_node_started(node_name, name)
     )
-    output = sync.pull_config_from_node(
-        env.node_communicator(), NodeAddresses(node_name), name
-    )
+    com_cmd = BoothGetConfig(env.report_processor, name)
+    com_cmd.set_targets([
+        env.get_node_target_factory().get_target_from_hostname(node_name)
+    ])
+    output = run_and_raise(env.get_node_communicator(), com_cmd)[0][1]
     try:
         env.booth.create_config(output["config"]["data"], True)
         if (
