@@ -8,6 +8,7 @@ from contextlib import contextmanager
 from functools import partial
 
 from pcs.common import report_codes
+from pcs.common.tools import Version
 from pcs.lib import reports
 from pcs.lib.cib import resource
 from pcs.lib.cib.resource import operations, remote_node, guest_node
@@ -457,7 +458,7 @@ def create_into_bundle(
             or
             resource.common.are_meta_disabled(meta_attributes)
         ),
-        required_cib_version=(2, 8, 0)
+        required_cib_version=Version(2, 8, 0)
     ) as resources_section:
         _check_special_cases(
             env,
@@ -481,7 +482,9 @@ def create_into_bundle(
             resource.common.disable(primitive_element)
         resource.bundle.add_resource(
             find_element_by_tag_and_id(
-                "bundle", resources_section, bundle_id
+                resource.bundle.TAG,
+                resources_section,
+                bundle_id
             ),
             primitive_element
         )
@@ -523,7 +526,7 @@ def bundle_create(
             or
             resource.common.are_meta_disabled(meta_attributes)
         ),
-        required_cib_version=(2, 8, 0)
+        required_cib_version=Version(2, 8, 0)
     ) as resources_section:
         # no need to run validations related to remote and guest nodes as those
         # nodes can only be created from primitive resources
@@ -589,7 +592,7 @@ def bundle_update(
         env,
         wait,
         [bundle_id],
-        required_cib_version=(2, 8, 0)
+        required_cib_version=Version(2, 8, 0)
     ) as resources_section:
         # no need to run validations related to remote and guest nodes as those
         # nodes can only be created from primitive resources
@@ -682,7 +685,7 @@ def _resource_list_enable_disable(resource_el_list, func, cluster_state):
             report_list.append(
                 reports.id_not_found(
                     res_id,
-                    id_description="resource/clone/master/group/bundle"
+                    ["primitive", "clone", "master", "group", "bundle"]
                )
             )
     return report_list
@@ -784,8 +787,7 @@ def _find_resources_or_raise(
                     find_element_by_tag_and_id(
                         resource_tags,
                         resources_section,
-                        res_id,
-                        id_description="resource/clone/master/group/bundle"
+                        res_id
                     )
                 )
             )
