@@ -41,6 +41,14 @@ from pcs.lib.validate import (
 )
 
 
+UNSUPPORTED_SBD_OPTION_LIST = [
+    "SBD_WATCHDOG_DEV", "SBD_OPTS", "SBD_PACEMAKER", "SBD_DEVICE"
+]
+ALLOWED_SBD_OPTION_LIST = [
+    "SBD_DELAY_START", "SBD_STARTMODE", "SBD_WATCHDOG_TIMEOUT"
+]
+
+
 def _validate_sbd_options(sbd_config, allow_unknown_opts=False):
     """
     Validate user SBD configuration. Options 'SBD_WATCHDOG_DEV' and 'SBD_OPTS'
@@ -51,22 +59,16 @@ def _validate_sbd_options(sbd_config, allow_unknown_opts=False):
     """
 
     report_item_list = []
-    unsupported_sbd_option_list = [
-        "SBD_WATCHDOG_DEV", "SBD_OPTS", "SBD_PACEMAKER", "SBD_DEVICE"
-    ]
-    allowed_sbd_options = [
-        "SBD_DELAY_START", "SBD_STARTMODE", "SBD_WATCHDOG_TIMEOUT"
-    ]
     for sbd_opt in sbd_config:
-        if sbd_opt in unsupported_sbd_option_list:
-            report_item_list.append(reports.invalid_option(
-                [sbd_opt], allowed_sbd_options, None
+        if sbd_opt in UNSUPPORTED_SBD_OPTION_LIST:
+            report_item_list.append(reports.invalid_options(
+                [sbd_opt], ALLOWED_SBD_OPTION_LIST, None
             ))
 
-        elif sbd_opt not in allowed_sbd_options:
-            report_item_list.append(reports.invalid_option(
+        elif sbd_opt not in ALLOWED_SBD_OPTION_LIST:
+            report_item_list.append(reports.invalid_options(
                 [sbd_opt],
-                allowed_sbd_options,
+                ALLOWED_SBD_OPTION_LIST,
                 None,
                 severity=(
                     Severities.WARNING if allow_unknown_opts
@@ -213,12 +215,13 @@ def enable_sbd(
 
     lib_env.report_processor.process_list(
         _check_node_names_in_cluster(
-            node_list, watchdog_dict.keys() + node_device_dict.keys()
+            node_list,
+            list(watchdog_dict.keys()) + list(node_device_dict.keys())
         )
         +
         _validate_watchdog_dict(full_watchdog_dict)
         +
-        _validate_device_dict(full_device_dict) if using_devices else []
+        (_validate_device_dict(full_device_dict) if using_devices else [])
         +
         _validate_sbd_options(sbd_options, allow_unknown_opts)
     )
