@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 from pcs.test.tools.pcs_unittest import TestCase
@@ -13,10 +12,8 @@ from pcs.common import report_codes
 from pcs.lib.commands.constraint import ticket as ticket_command
 from pcs.lib.errors import ReportItemSeverity as severities
 from pcs.lib.test.misc import get_mocked_env
-from pcs.test.tools.assertions import (
-    assert_xml_equal,
-    assert_raise_library_error
-)
+from pcs.test.tools.assertions import assert_raise_library_error
+from pcs.test.tools.command_env import get_env_tools
 from pcs.test.tools.misc import get_test_resource as rc
 from pcs.test.tools.xml import get_xml_manipulation_creator_from_file
 
@@ -29,31 +26,38 @@ class CreateTest(TestCase):
         )
 
     def test_sucess_create(self):
-        resource_xml = '<primitive id="resourceA" class="service" type="exim"/>'
-        cib = (
-            self.create_cib()
-                .append_to_first_tag_name('resources', resource_xml)
-        )
-
-        env = get_mocked_env(cib_data=str(cib))
-        ticket_command.create(env, "ticketA", "resourceA", {
-            "loss-policy": "fence",
-            "rsc-role": "master"
-        })
-
-        assert_xml_equal(
-            env._get_cib_xml(),
-            str(cib.append_to_first_tag_name(
-                'constraints', """
-                    <rsc_ticket
-                        id="ticket-ticketA-resourceA-Master"
-                        rsc="resourceA"
-                        rsc-role="Master"
-                        ticket="ticketA"
-                        loss-policy="fence"
-                    />
+        env_assist, config = get_env_tools(test_case=self)
+        (config
+            .runner.cib.load(
+                resources="""
+                    <resources>
+                        <primitive id="resourceA" class="service" type="exim"/>
+                    </resources>
                 """
-            ))
+            )
+            .env.push_cib(
+                optional_in_conf="""
+                    <constraints>
+                        <rsc_ticket
+                            id="ticket-ticketA-resourceA-Master"
+                            rsc="resourceA"
+                            rsc-role="Master"
+                            ticket="ticketA"
+                            loss-policy="fence"
+                        />
+                    </constraints>
+                """
+            )
+         )
+
+        ticket_command.create(
+            env_assist.get_env(),
+            "ticketA",
+            "resourceA",
+            {
+                "loss-policy": "fence",
+                "rsc-role": "master"
+            }
         )
 
     def test_refuse_for_nonexisting_resource(self):
@@ -64,8 +68,16 @@ class CreateTest(TestCase):
             ),
             (
                 severities.ERROR,
-                report_codes.RESOURCE_DOES_NOT_EXIST,
-                {"resource_id": "resourceA"},
+                report_codes.ID_NOT_FOUND,
+                {
+                    "context_type": "cib",
+                    "context_id": "",
+                    "id": "resourceA",
+                    "expected_types": [
+                        "bundle", "clone", "group", "master", "primitive"
+                    ],
+                },
+                None
             ),
         )
 
