@@ -2,11 +2,12 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
+import re
+
 from pcs.common import report_codes
-from pcs.lib import reports
+from pcs.lib import reports, validate
 from pcs.lib.errors import ReportItemSeverity, LibraryError
 from pcs.lib.corosync import config_parser
 from pcs.lib.node import NodeAddresses, NodeAddressesList
@@ -27,7 +28,7 @@ class ConfigFacade(object):
         "last_man_standing",
         "last_man_standing_window",
     )
-
+    __QUORUM_DEVICE_HEURISTICS_EXEC_NAME_RE = re.compile("^exec_[^.:{}#\s]+$")
 
     @classmethod
     def from_string(cls, config_string):
@@ -147,7 +148,7 @@ class ConfigFacade(object):
             allowed_names = self.__class__.QUORUM_OPTIONS
             if name not in allowed_names:
                 report_items.append(
-                    reports.invalid_option(name, allowed_names, "quorum")
+                    reports.invalid_options([name], allowed_names, "quorum")
                 )
                 continue
 
@@ -200,6 +201,7 @@ class ConfigFacade(object):
         model = None
         model_options = {}
         generic_options = {}
+        heuristics_options = {}
         for quorum in self.config.get_sections("quorum"):
             for device in quorum.get_sections("device"):
                 for name, value in device.get_attributes():
@@ -208,24 +210,34 @@ class ConfigFacade(object):
                     else:
                         generic_options[name] = value
                 for subsection in device.get_sections():
+                    if subsection.name == "heuristics":
+                        heuristics_options.update(subsection.get_attributes())
+                        continue
                     if subsection.name not in model_options:
                         model_options[subsection.name] = {}
                     model_options[subsection.name].update(
                         subsection.get_attributes()
                     )
-        return model, model_options.get(model, {}), generic_options
+        return (
+            model,
+            model_options.get(model, {}),
+            generic_options,
+            heuristics_options,
+        )
 
     def add_quorum_device(
         self, report_processor, model, model_options, generic_options,
-        force_model=False, force_options=False,
+        heuristics_options, force_model=False, force_options=False,
     ):
         """
         Add quorum device configuration
-        model quorum device model
-        model_options model specific options dict
-        generic_options generic quorum device options dict
-        force_model continue even if the model is not valid
-        force_options continue even if options are not valid
+
+        string model -- quorum device model
+        dict model_options -- model specific options
+        dict generic_options -- generic quorum device options
+        dict heuristics_options -- heuristics options
+        bool force_model -- continue even if the model is not valid
+        bool force_options -- continue even if options are not valid
         """
         # validation
         if self.has_quorum_device():
@@ -244,6 +256,11 @@ class ConfigFacade(object):
                 generic_options,
                 force=force_options
             )
+            +
+            self.__validate_quorum_device_add_heuristics(
+                heuristics_options,
+                force_options=force_options
+            )
         )
 
         # configuration cleanup
@@ -284,19 +301,30 @@ class ConfigFacade(object):
         new_model = config_parser.Section(model)
         self.__set_section_options([new_model], model_options)
         new_device.add_section(new_model)
+        new_heuristics = config_parser.Section("heuristics")
+        self.__set_section_options([new_heuristics], heuristics_options)
+        new_device.add_section(new_heuristics)
+
+        if self.__is_heuristics_enabled_with_no_exec():
+            report_processor.process(
+                reports.corosync_quorum_heuristics_enabled_with_no_exec()
+            )
+
         self.__update_qdevice_votes()
         self.__update_two_node()
         self.__remove_empty_sections(self.config)
 
     def update_quorum_device(
         self, report_processor, model_options, generic_options,
-        force_options=False
+        heuristics_options, force_options=False
     ):
         """
         Update existing quorum device configuration
-        model_options model specific options dict
-        generic_options generic quorum device options dict
-        force_options continue even if options are not valid
+
+        dict model_options -- model specific options
+        dict generic_options -- generic quorum device options
+        dict heuristics_options -- heuristics options
+        bool force_options -- continue even if options are not valid
         """
         # validation
         if not self.has_quorum_device():
@@ -318,21 +346,61 @@ class ConfigFacade(object):
                 generic_options,
                 force=force_options
             )
+            +
+            self.__validate_quorum_device_update_heuristics(
+                heuristics_options,
+                force_options=force_options
+            )
         )
+
         # set new configuration
         device_sections = []
         model_sections = []
+        heuristics_sections = []
+
         for quorum in self.config.get_sections("quorum"):
             device_sections.extend(quorum.get_sections("device"))
             for device in quorum.get_sections("device"):
                 model_sections.extend(device.get_sections(model))
+                heuristics_sections.extend(device.get_sections("heuristics"))
+        # we know device sections exist, otherwise the function would exit at
+        # has_quorum_device line above
+        if not model_sections:
+            new_model = config_parser.Section(model)
+            device_sections[-1].add_section(new_model)
+            model_sections.append(new_model)
+        if not heuristics_sections:
+            new_heuristics = config_parser.Section("heuristics")
+            device_sections[-1].add_section(new_heuristics)
+            heuristics_sections.append(new_heuristics)
+
         self.__set_section_options(device_sections, generic_options)
         self.__set_section_options(model_sections, model_options)
+        self.__set_section_options(heuristics_sections, heuristics_options)
+
+        if self.__is_heuristics_enabled_with_no_exec():
+            report_processor.process(
+                reports.corosync_quorum_heuristics_enabled_with_no_exec()
+            )
+
         self.__update_qdevice_votes()
         self.__update_two_node()
         self.__remove_empty_sections(self.config)
         self._need_qdevice_reload = True
 
+    def remove_quorum_device_heuristics(self):
+        """
+        Remove quorum device heuristics configuration
+        """
+        if not self.has_quorum_device():
+            raise LibraryError(reports.qdevice_not_defined())
+        for quorum in self.config.get_sections("quorum"):
+            for device in quorum.get_sections("device"):
+                for heuristics in device.get_sections("heuristics"):
+                    device.del_section(heuristics)
+        self.__remove_empty_sections(self.config)
+        self._need_qdevice_reload = True
+
     def remove_quorum_device(self):
         """
         Remove all quorum device configuration
@@ -356,9 +424,13 @@ class ConfigFacade(object):
                 "model",
                 model,
                 allowed_values,
-                ReportItemSeverity.WARNING if force_model
-                    else ReportItemSeverity.ERROR,
-                None if force_model else report_codes.FORCE_QDEVICE_MODEL
+                severity=(
+                    ReportItemSeverity.WARNING if force_model
+                    else ReportItemSeverity.ERROR
+                ),
+                forceable=(
+                    None if force_model else report_codes.FORCE_QDEVICE_MODEL
+                )
             ))
 
         return report_items
@@ -370,7 +442,7 @@ class ConfigFacade(object):
             return self.__validate_quorum_device_model_net_options(
                 model_options,
                 need_required,
-                force
+                force=force
             )
         return []
 
@@ -386,6 +458,7 @@ class ConfigFacade(object):
         ])
         allowed_options = required_options | optional_options
         model_options_names = frozenset(model_options.keys())
+        missing_options = []
         report_items = []
         severity = (
             ReportItemSeverity.WARNING if force else ReportItemSeverity.ERROR
@@ -393,26 +466,23 @@ class ConfigFacade(object):
         forceable = None if force else report_codes.FORCE_OPTIONS
 
         if need_required:
-            for missing in sorted(required_options - model_options_names):
-                report_items.append(reports.required_option_is_missing(missing))
+            missing_options += required_options - model_options_names
 
         for name, value in sorted(model_options.items()):
             if name not in allowed_options:
-                report_items.append(reports.invalid_option(
-                    name,
+                report_items.append(reports.invalid_options(
+                    [name],
                     allowed_options,
                     "quorum device model",
-                    severity,
-                    forceable
+                    severity=severity,
+                    forceable=forceable
                 ))
                 continue
 
             if value == "":
                 # do not allow to remove required options
                 if name in required_options:
-                    report_items.append(
-                        reports.required_option_is_missing(name)
-                    )
+                    missing_options.append(name)
                 else:
                     continue
 
@@ -420,7 +490,11 @@ class ConfigFacade(object):
                 allowed_values = ("ffsplit", "lms")
                 if value not in allowed_values:
                     report_items.append(reports.invalid_option_value(
-                        name, value, allowed_values, severity, forceable
+                        name,
+                        value,
+                        allowed_values,
+                        severity=severity,
+                        forceable=forceable
                     ))
 
             if name == "connect_timeout":
@@ -428,14 +502,22 @@ class ConfigFacade(object):
                 if not (value.isdigit() and minimum <= int(value) <= maximum):
                     min_max = "{min}-{max}".format(min=minimum, max=maximum)
                     report_items.append(reports.invalid_option_value(
-                        name, value, min_max, severity, forceable
+                        name,
+                        value,
+                        min_max,
+                        severity=severity,
+                        forceable=forceable
                     ))
 
             if name == "force_ip_version":
                 allowed_values = ("0", "4", "6")
                 if value not in allowed_values:
                     report_items.append(reports.invalid_option_value(
-                        name, value, allowed_values, severity, forceable
+                        name,
+                        value,
+                        allowed_values,
+                        severity=severity,
+                        forceable=forceable
                     ))
 
             if name == "port":
@@ -443,7 +525,11 @@ class ConfigFacade(object):
                 if not (value.isdigit() and minimum <= int(value) <= maximum):
                     min_max = "{min}-{max}".format(min=minimum, max=maximum)
                     report_items.append(reports.invalid_option_value(
-                        name, value, min_max, severity, forceable
+                        name,
+                        value,
+                        min_max,
+                        severity=severity,
+                        forceable=forceable
                     ))
 
             if name == "tie_breaker":
@@ -452,9 +538,18 @@ class ConfigFacade(object):
                 if value not in allowed_nonid + node_ids:
                     allowed_values = allowed_nonid + ["valid node id"]
                     report_items.append(reports.invalid_option_value(
-                        name, value, allowed_values, severity, forceable
+                        name,
+                        value,
+                        allowed_values,
+                        severity=severity,
+                        forceable=forceable
                     ))
 
+        if missing_options:
+            report_items.append(
+                reports.required_option_is_missing(sorted(missing_options))
+            )
+
         return report_items
 
     def __validate_quorum_device_generic_options(
@@ -475,12 +570,15 @@ class ConfigFacade(object):
             if name not in allowed_options:
                 # model is never allowed in generic options, it is passed
                 # in its own argument
-                report_items.append(reports.invalid_option(
-                    name,
+                report_items.append(reports.invalid_options(
+                    [name],
                     allowed_options,
                     "quorum device",
-                    severity if name != "model" else ReportItemSeverity.ERROR,
-                    forceable if name != "model" else None
+                    severity=(
+                        severity if name != "model"
+                        else ReportItemSeverity.ERROR
+                    ),
+                    forceable=(forceable if name != "model" else None)
                 ))
                 continue
 
@@ -489,11 +587,171 @@ class ConfigFacade(object):
 
             if not value.isdigit():
                 report_items.append(reports.invalid_option_value(
-                    name, value, "positive integer", severity, forceable
+                    name,
+                    value,
+                    "positive integer",
+                    severity=severity,
+                    forceable=forceable
                 ))
 
         return report_items
 
+    def __split_heuristics_exec_options(self, heuristics_options):
+        options_exec = dict()
+        options_nonexec = dict()
+        for name, value in heuristics_options.items():
+            if name.startswith("exec_"):
+                options_exec[name] = value
+            else:
+                options_nonexec[name] = value
+        return options_nonexec, options_exec
+
+    def __get_heuristics_options_validators(
+        self, allow_empty_values=False, force_options=False
+    ):
+        validators = {
+            "mode": validate.value_in(
+                "mode",
+                ("off", "on", "sync"),
+                code_to_allow_extra_values=report_codes.FORCE_OPTIONS,
+                allow_extra_values=force_options
+            ),
+            "interval": validate.value_positive_integer(
+                "interval",
+                code_to_allow_extra_values=report_codes.FORCE_OPTIONS,
+                allow_extra_values=force_options
+            ),
+            "sync_timeout": validate.value_positive_integer(
+                "sync_timeout",
+                code_to_allow_extra_values=report_codes.FORCE_OPTIONS,
+                allow_extra_values=force_options
+            ),
+            "timeout": validate.value_positive_integer(
+                "timeout",
+                code_to_allow_extra_values=report_codes.FORCE_OPTIONS,
+                allow_extra_values=force_options
+            ),
+        }
+        if not allow_empty_values:
+            # make sure to return a list even in python3 so we can call append
+            # on it
+            return list(validators.values())
+        return [
+            validate.value_empty_or_valid(option_name, validator)
+            for option_name, validator in validators.items()
+        ]
+
+    def __validate_heuristics_noexec_option_names(
+        self, options_nonexec, force_options=False
+    ):
+        return validate.names_in(
+            ("mode", "interval", "sync_timeout", "timeout"),
+            options_nonexec.keys(),
+            "heuristics",
+            report_codes.FORCE_OPTIONS,
+            allow_extra_names=force_options,
+            allowed_option_patterns=["exec_NAME"]
+        )
+
+    def __validate_heuristics_exec_option_names(self, options_exec):
+        # We must be strict and do not allow to override this validation,
+        # otherwise setting a cratfed exec_NAME could be misused for setting
+        # arbitrary corosync.conf settings.
+        regexp = self.__QUORUM_DEVICE_HEURISTICS_EXEC_NAME_RE
+        report_list = []
+        valid_options = []
+        not_valid_options = []
+        for name in options_exec:
+            if regexp.match(name) is None:
+                not_valid_options.append(name)
+            else:
+                valid_options.append(name)
+        if not_valid_options:
+            report_list.append(
+                reports.invalid_userdefined_options(
+                    not_valid_options,
+                    "exec_NAME cannot contain '.:{}#' and whitespace characters",
+                    "heuristics",
+                    severity=ReportItemSeverity.ERROR,
+                    forceable=None
+                )
+            )
+        return report_list, valid_options
+
+    def __validate_quorum_device_add_heuristics(
+        self, heuristics_options, force_options=False
+    ):
+        report_list = []
+        options_nonexec, options_exec = self.__split_heuristics_exec_options(
+            heuristics_options
+        )
+        validators = self.__get_heuristics_options_validators(
+            force_options=force_options
+        )
+        exec_options_reports, valid_exec_options = (
+            self.__validate_heuristics_exec_option_names(options_exec)
+        )
+        for option in valid_exec_options:
+            validators.append(
+                validate.value_not_empty(option, "a command to be run")
+            )
+        report_list.extend(
+            validate.run_collection_of_option_validators(
+                heuristics_options, validators
+            )
+            +
+            self.__validate_heuristics_noexec_option_names(
+                options_nonexec, force_options=force_options
+            )
+            +
+            exec_options_reports
+        )
+        return report_list
+
+    def __validate_quorum_device_update_heuristics(
+        self, heuristics_options, force_options=False
+    ):
+        report_list = []
+        options_nonexec, options_exec = self.__split_heuristics_exec_options(
+            heuristics_options
+        )
+        validators = self.__get_heuristics_options_validators(
+            allow_empty_values=True, force_options=force_options
+        )
+        # no validation necessary for values of valid exec options - they are
+        # either empty (meaning they should be removed) or nonempty strings
+        exec_options_reports, dummy_valid_exec_options = (
+            self.__validate_heuristics_exec_option_names(options_exec)
+        )
+        report_list.extend(
+            validate.run_collection_of_option_validators(
+                heuristics_options, validators
+            )
+            +
+            self.__validate_heuristics_noexec_option_names(
+                options_nonexec, force_options=force_options
+            )
+            +
+            exec_options_reports
+        )
+        return report_list
+
+    def __is_heuristics_enabled_with_no_exec(self):
+        regexp = self.__QUORUM_DEVICE_HEURISTICS_EXEC_NAME_RE
+        mode = None
+        exec_found = False
+        for quorum in self.config.get_sections("quorum"):
+            for device in quorum.get_sections("device"):
+                for heuristics in device.get_sections("heuristics"):
+                    for name, value in heuristics.get_attributes():
+                        if name == "mode" and value:
+                            # Cannot break, must go through all modes, the last
+                            # one matters
+                            mode = value
+                        elif regexp.match(name) and value:
+                            exec_found = True
+        return not exec_found and mode in ("on", "sync")
+
     def __update_two_node(self):
         # get relevant status
         has_quorum_device = self.has_quorum_device()
