@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 from functools import partial
@@ -165,7 +164,7 @@ def required_option_is_missing(
     """
     required option has not been specified, command cannot continue
     list name is/are required but was not entered
-    option_type decsribes the option
+    option_type describes the option
     severity report item severity
     forceable is this report item forceable? by what cathegory?
     """
@@ -186,8 +185,8 @@ def prerequisite_option_is_missing(
     if the option_name is specified, the prerequisite_option must be specified
     string option_name -- an option which depends on the prerequisite_option
     string prerequisite_name -- the prerequisite option
-    string option_type -- decsribes the option
-    string prerequisite_type -- decsribes the prerequisite_option
+    string option_type -- describes the option
+    string prerequisite_type -- describes the prerequisite_option
     """
     return ReportItem.error(
         report_codes.PREREQUISITE_OPTION_IS_MISSING,
@@ -205,7 +204,7 @@ def required_option_of_alternatives_is_missing(
     """
     at least one option has to be specified
     iterable option_names -- options from which at least one has to be specified
-    string option_type -- decsribes the option
+    string option_type -- describes the option
     """
     severity = ReportItemSeverity.ERROR
     forceable = None
@@ -219,27 +218,59 @@ def required_option_of_alternatives_is_missing(
         }
     )
 
-def invalid_option(
-    option_names, allowed_options, option_type,
+def invalid_options(
+    option_names, allowed_options, option_type, allowed_option_patterns=None,
     severity=ReportItemSeverity.ERROR, forceable=None
 ):
     """
-    specified option name is not valid, usualy an error or a warning
-    list option_names specified invalid option names
-    allowed_options iterable of possible allowed option names
-    option_type decsribes the option
-    severity report item severity
-    forceable is this report item forceable? by what cathegory?
-    """
+    specified option names are not valid, usualy an error or a warning
 
+    list option_names -- specified invalid option names
+    list allowed_options -- possible allowed option names
+    string option_type -- describes the option
+    list allowed_option_patterns -- allowed user defind options patterns
+    string severity -- report item severity
+    mixed forceable -- is this report item forceable? by what cathegory?
+    """
     return ReportItem(
-        report_codes.INVALID_OPTION,
+        report_codes.INVALID_OPTIONS,
         severity,
         forceable,
         info={
             "option_names": option_names,
             "option_type": option_type,
             "allowed": sorted(allowed_options),
+            "allowed_patterns": sorted(allowed_option_patterns or []),
+        }
+    )
+
+def invalid_userdefined_options(
+    option_names, allowed_description, option_type,
+    severity=ReportItemSeverity.ERROR, forceable=None
+):
+    """
+    specified option names defined by a user are not valid
+
+    This is different than invalid_options. In this case, the options are
+    supposed to be defined by a user. This report carries information that the
+    option names do not meet requirements, i.e. contain not allowed characters.
+    Invalid_options is used when the options are predefined by pcs (or
+    underlying tools).
+
+    list option_names -- specified invalid option names
+    string allowed_description -- describes what option names should look like
+    string option_type -- describes the option
+    string severity -- report item severity
+    mixed forceable -- is this report item forceable? by what cathegory?
+    """
+    return ReportItem(
+        report_codes.INVALID_USERDEFINED_OPTIONS,
+        severity,
+        forceable,
+        info={
+            "option_names": sorted(option_names),
+            "option_type": option_type,
+            "allowed_description": allowed_description,
         }
     )
 
@@ -308,7 +339,7 @@ def mutually_exclusive_options(option_names, option_type):
     """
     entered options can not coexist
     set option_names contain entered mutually exclusive options
-    string option_type decsribes the option
+    string option_type describes the option
     """
     return ReportItem.error(
         report_codes.MUTUALLY_EXCLUSIVE_OPTIONS,
@@ -318,6 +349,20 @@ def mutually_exclusive_options(option_names, option_type):
         },
     )
 
+def invalid_cib_content(report):
+    """
+    Given cib content is not valid.
+    string report -- is human readable explanation of a cib invalidity. For
+        example a stderr of `crm_verify`.
+    """
+    return ReportItem.error(
+        report_codes.INVALID_CIB_CONTENT,
+        info={
+            "report": report,
+        }
+    )
+
+
 
 def invalid_id_is_empty(id, id_description):
     """
@@ -487,6 +532,20 @@ def node_communication_not_connected(node, reason):
         }
     )
 
+
+def node_communication_no_more_addresses(node, request):
+    """
+    request failed and there are no more addresses to try it again
+    """
+    return ReportItem.warning(
+        report_codes.NODE_COMMUNICATION_NO_MORE_ADDRESSES,
+        info={
+            "node": node,
+            "request": request,
+        }
+    )
+
+
 def node_communication_error_not_authorized(
     node, command, reason,
     severity=ReportItemSeverity.ERROR, forceable=None
@@ -626,12 +685,35 @@ def node_communication_error_timed_out(
         forceable=forceable
     )
 
-def node_communication_proxy_is_set():
+def node_communication_proxy_is_set(node=None, address=None):
     """
     Warning when connection failed and there is proxy set in environment
     variables
     """
-    return ReportItem.warning(report_codes.NODE_COMMUNICATION_PROXY_IS_SET)
+    return ReportItem.warning(
+        report_codes.NODE_COMMUNICATION_PROXY_IS_SET,
+        info={
+            "node": node,
+            "address": address,
+        }
+    )
+
+
+def node_communication_retrying(node, failed_address, next_address, request):
+    """
+    Request failed due communication error connecting via specified address,
+    therefore trying another address if there is any.
+    """
+    return ReportItem.warning(
+        report_codes.NODE_COMMUNICATION_RETRYING,
+        info={
+            "node": node,
+            "failed_address": failed_address,
+            "next_address": next_address,
+            "request": request,
+        }
+    )
+
 
 def cannot_add_node_is_in_cluster(node):
     """
@@ -656,6 +738,12 @@ def cannot_add_node_is_running_service(node, service):
         }
     )
 
+def defaults_can_be_overriden():
+    """
+    Warning when settings defaults (op_defaults, rsc_defaults...)
+    """
+    return ReportItem.warning(report_codes.DEFAULTS_CAN_BE_OVERRIDEN)
+
 def corosync_config_distribution_started():
     """
     corosync configuration is about to be sent to nodes
@@ -744,6 +832,14 @@ def corosync_quorum_get_status_error(reason):
         }
     )
 
+def corosync_quorum_heuristics_enabled_with_no_exec():
+    """
+    no exec_ is specified, therefore heuristics are effectively disabled
+    """
+    return ReportItem.warning(
+        report_codes.COROSYNC_QUORUM_HEURISTICS_ENABLED_WITH_NO_EXEC
+    )
+
 def corosync_quorum_set_expected_votes_error(reason):
     """
     unable to set expcted votes in a live cluster
@@ -1084,18 +1180,20 @@ def object_with_id_in_unexpected_context(
     )
 
 
-def id_not_found(id, id_description, context_type="", context_id=""):
+def id_not_found(id, expected_types, context_type="", context_id=""):
     """
     specified id does not exist in CIB, user referenced a nonexisting id
-    string id specified id
-    string id_description decribe id's role
-    string context_id specifies the search area
+
+    string id -- specified id
+    list expected_types -- list of id's roles - expected types with the id
+    string context_type -- context_id's role / type
+    string context_id -- specifies the search area
     """
     return ReportItem.error(
         report_codes.ID_NOT_FOUND,
         info={
             "id": id,
-            "id_description": id_description,
+            "expected_types": sorted(expected_types),
             "context_type": context_type,
             "context_id": context_id,
         }
@@ -1243,12 +1341,15 @@ def cib_load_error_scope_missing(scope, reason):
         }
     )
 
-def cib_load_error_invalid_format():
+def cib_load_error_invalid_format(reason):
     """
     cib does not conform to the schema
     """
     return ReportItem.error(
         report_codes.CIB_LOAD_ERROR_BAD_FORMAT,
+        info={
+            "reason": reason,
+        }
     )
 
 def cib_missing_mandatory_section(section_name):
@@ -1289,6 +1390,37 @@ def cib_save_tmp_error(reason):
         }
     )
 
+def cib_diff_error(reason, cib_old, cib_new):
+    """
+    cannot obtain a diff of CIBs
+    string reason -- error description
+    string cib_old -- the CIB to be diffed against
+    string cib_new -- the CIB diffed against the old cib
+    """
+    return ReportItem.error(
+        report_codes.CIB_DIFF_ERROR,
+        info={
+            "reason": reason,
+            "cib_old": cib_old,
+            "cib_new": cib_new,
+        }
+    )
+
+def cib_push_forced_full_due_to_crm_feature_set(required_set, current_set):
+    """
+    Pcs uses the "push full CIB" approach so race conditions may occur.
+
+    pcs.common.tools.Version required_set -- crm_feature_set required for diff
+    pcs.common.tools.Version current_set -- actual CIB crm_feature_set
+    """
+    return ReportItem.warning(
+        report_codes.CIB_PUSH_FORCED_FULL_DUE_TO_CRM_FEATURE_SET,
+        info={
+            "required_set": str(required_set),
+            "current_set": str(current_set),
+        }
+    )
+
 def cluster_state_cannot_load(reason):
     """
     cannot load cluster status from crm_mon, crm_mon exited with non-zero code
@@ -1351,10 +1483,11 @@ def wait_for_idle_not_live_cluster():
 
 def resource_cleanup_error(reason, resource=None, node=None):
     """
-    an error occured when deleting resource history in pacemaker
-    string reason error description
-    string resource resource which has been cleaned up
-    string node node which has been cleaned up
+    An error occured when deleting resource failed operations in pacemaker
+
+    string reason -- error description
+    string resource -- resource which has been cleaned up
+    string node -- node which has been cleaned up
     """
     return ReportItem.error(
         report_codes.RESOURCE_CLEANUP_ERROR,
@@ -1365,13 +1498,31 @@ def resource_cleanup_error(reason, resource=None, node=None):
         }
     )
 
-def resource_cleanup_too_time_consuming(threshold):
+def resource_refresh_error(reason, resource=None, node=None):
     """
-    resource cleanup will execute more than threshold operations in a cluster
-    threshold current threshold for trigerring this error
+    An error occured when deleting resource history in pacemaker
+
+    string reason -- error description
+    string resource -- resource which has been cleaned up
+    string node -- node which has been cleaned up
     """
     return ReportItem.error(
-        report_codes.RESOURCE_CLEANUP_TOO_TIME_CONSUMING,
+        report_codes.RESOURCE_REFRESH_ERROR,
+        info={
+            "reason": reason,
+            "resource": resource,
+            "node": node,
+        }
+    )
+
+def resource_refresh_too_time_consuming(threshold):
+    """
+    Resource refresh would execute more than threshold operations in a cluster
+
+    int threshold -- current threshold for trigerring this error
+    """
+    return ReportItem.error(
+        report_codes.RESOURCE_REFRESH_TOO_TIME_CONSUMING,
         info={"threshold": threshold},
         forceable=report_codes.FORCE_LOAD_THRESHOLD
     )
@@ -2409,14 +2560,14 @@ def unable_to_upgrade_cib_to_required_version(
     """
     Unable to upgrade CIB to minimal required schema version.
 
-    current_version -- current version of CIB schema
-    required_version -- required version of CIB schema
+    pcs.common.tools.Version current_version -- current version of CIB schema
+    pcs.common.tools.Version required_version -- required version of CIB schema
     """
     return ReportItem.error(
         report_codes.CIB_UPGRADE_FAILED_TO_MINIMAL_REQUIRED_VERSION,
         info={
-            "required_version": "{0}.{1}.{2}".format(*required_version),
-            "current_version": "{0}.{1}.{2}".format(*current_version)
+            "required_version": str(required_version),
+            "current_version": str(current_version)
         }
     )
 
@@ -2691,3 +2842,29 @@ def use_command_node_remove_guest(
         info={},
         forceable=forceable
     )
+
+def tmp_file_write(file_path, content):
+    """
+    It has been written into a temporary file
+    string file_path -- the file path
+    string content -- content which has been written
+    """
+    return ReportItem.debug(
+        report_codes.TMP_FILE_WRITE,
+        info={
+            "file_path": file_path,
+            "content": content,
+        }
+    )
+
+
+def unable_to_perform_operation_on_any_node():
+    """
+    This report is raised whenever
+    pcs.lib.communication.tools.OneByOneStrategyMixin strategy mixin is used
+    for network communication and operation failed on all available hosts and
+    because of this it is not possible to continue.
+    """
+    return ReportItem.error(
+        report_codes.UNABLE_TO_PERFORM_OPERATION_ON_ANY_NODE,
+    )
