@@ -1,14 +1,17 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
+from __future__ import (
+    absolute_import,
+    division,
+    print_function,
+)
 
 import sys
 import json
-from xml.dom.minidom import parseString
 
-import usage
-import utils
+from pcs import (
+    node,
+    usage,
+    utils,
+)
 
 def property_cmd(argv):
     if len(argv) == 0:
@@ -99,9 +102,10 @@ def unset_property(argv):
         utils.replace_cib_configuration(cib_dom)
 
 def list_property(argv):
-    print_all = False
-    if len(argv) == 0:
-        print_all = True
+    print_all = len(argv) == 0
+
+    if "--all" in utils.pcs_options and "--defaults" in utils.pcs_options:
+        utils.err("you cannot specify both --all and --defaults")
 
     if "--all" in utils.pcs_options or "--defaults" in utils.pcs_options:
         if len(argv) != 0:
@@ -111,23 +115,21 @@ def list_property(argv):
         properties = {}
 
     if "--defaults" not in utils.pcs_options:
-        properties = get_set_properties(
+        properties = utils.get_set_properties(
             None if print_all else argv[0],
             properties
         )
 
     print("Cluster Properties:")
     for prop,val in sorted(properties.items()):
-        print(" " + prop + ": " + val)
+        print(" {0}: {1}".format(prop, val))
 
-    node_attributes = utils.get_node_attributes()
+    node_attributes = utils.get_node_attributes(
+        filter_attr=(None if print_all else argv[0])
+    )
     if node_attributes:
         print("Node Attributes:")
-        for node in sorted(node_attributes):
-            line_parts = [" " + node + ":"]
-            for attr in node_attributes[node]:
-                line_parts.append(attr)
-            print(" ".join(line_parts))
+        node.attribute_print(node_attributes)
 
 def get_default_properties():
     parameters = {}
@@ -136,16 +138,3 @@ def get_default_properties():
         parameters[name] = prop["default"]
     return parameters
 
-def get_set_properties(prop_name=None, defaults=None):
-    properties = {} if defaults is None else dict(defaults)
-    (output, retVal) = utils.run(["cibadmin","-Q","--scope", "crm_config"])
-    if retVal != 0:
-        utils.err("unable to get crm_config\n"+output)
-    dom = parseString(output)
-    de = dom.documentElement
-    crm_config_properties = de.getElementsByTagName("nvpair")
-    for prop in crm_config_properties:
-        if prop_name is None or (prop_name == prop.getAttribute("name")):
-            properties[prop.getAttribute("name")] = prop.getAttribute("value")
-    return properties
-
