@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 import shutil
@@ -21,7 +20,7 @@ class ResourceTest(
     TestCase,
     get_assert_pcs_effect_mixin(get_cib_resources)
 ):
-    empty_cib = rc("cib-empty-1.2.xml")
+    empty_cib = rc("cib-empty.xml")
     temp_cib = rc("temp-cib.xml")
 
     def setUp(self):
