@@ -2,9 +2,10 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
+import re
+
 from pcs.test.tools.misc import (
     get_test_resource as rc,
     skip_unless_pacemaker_supports_bundle,
@@ -51,9 +52,18 @@ class Success(ResourceTest):
             """<resources>
                 <primitive class="ocf" id="R" provider="heartbeat" type="Dummy">
                     <operations>
+                        <op id="R-migrate_from-interval-0s" interval="0s"
+                            name="migrate_from" timeout="20"
+                        />
+                        <op id="R-migrate_to-interval-0s" interval="0s"
+                            name="migrate_to" timeout="20"
+                        />
                         <op id="R-monitor-interval-10" interval="10"
                             name="monitor" timeout="20"
                         />
+                        <op id="R-reload-interval-0s" interval="0s"
+                            name="reload" timeout="20"
+                        />
                         <op id="R-start-interval-0s" interval="0s" name="start"
                             timeout="20"
                         />
@@ -376,9 +386,18 @@ class SuccessOperations(ResourceTest):
             """<resources>
                 <primitive class="ocf" id="R" provider="heartbeat" type="Dummy">
                     <operations>
+                        <op id="R-migrate_from-interval-0s" interval="0s"
+                            name="migrate_from" timeout="20"
+                        />
+                        <op id="R-migrate_to-interval-0s" interval="0s"
+                            name="migrate_to" timeout="20"
+                        />
                         <op id="R-monitor-interval-10" interval="10"
                             name="monitor" timeout="20"
                         />
+                        <op id="R-reload-interval-0s" interval="0s"
+                            name="reload" timeout="20"
+                        />
                         <op id="R-start-interval-0s" interval="0s" name="start"
                             timeout="20"
                         />
@@ -396,9 +415,18 @@ class SuccessOperations(ResourceTest):
             """<resources>
                 <primitive class="ocf" id="R" provider="heartbeat" type="Dummy">
                     <operations>
+                        <op id="R-migrate_from-interval-0s" interval="0s"
+                            name="migrate_from" timeout="20"
+                        />
+                        <op id="R-migrate_to-interval-0s" interval="0s"
+                            name="migrate_to" timeout="20"
+                        />
                         <op id="R-monitor-interval-10" interval="10"
                             name="monitor" timeout="20"
                         />
+                        <op id="R-reload-interval-0s" interval="0s"
+                            name="reload" timeout="20"
+                        />
                         <op id="R-start-interval-0s" interval="0s" name="start"
                             timeout="200"
                         />
@@ -438,6 +466,9 @@ class SuccessOperations(ResourceTest):
                         <op id="R-monitor-interval-11" interval="11"
                             name="monitor" role="Slave" timeout="20"
                         />
+                        <op id="R-notify-interval-0s" interval="0s"
+                            name="notify" timeout="5"
+                        />
                         <op id="R-start-interval-0s" interval="0s" name="start"
                             timeout="20"
                         />
@@ -663,9 +694,18 @@ class SuccessMaster(ResourceTest):
                             />
                         </instance_attributes>
                         <operations>
+                            <op id="R-migrate_from-interval-0s" interval="0s"
+                                name="migrate_from" timeout="20"
+                            />
+                            <op id="R-migrate_to-interval-0s" interval="0s"
+                                name="migrate_to" timeout="20"
+                            />
                             <op id="R-monitor-interval-10" interval="10"
                                 name="monitor" timeout="20"
                             />
+                            <op id="R-reload-interval-0s" interval="0s"
+                                name="reload" timeout="20"
+                            />
                             <op id="R-start-interval-0s" interval="0s"
                                 name="start" timeout="20"
                             />
@@ -798,9 +838,18 @@ class SuccessClone(ResourceTest):
                             />
                         </meta_attributes>
                         <operations>
+                            <op id="R-migrate_from-interval-0s" interval="0s"
+                                name="migrate_from" timeout="20"
+                            />
+                            <op id="R-migrate_to-interval-0s" interval="0s"
+                                name="migrate_to" timeout="20"
+                            />
                             <op id="R-monitor-interval-10" interval="10"
                                 name="monitor" timeout="20"
                             />
+                            <op id="R-reload-interval-0s" interval="0s"
+                                name="reload" timeout="20"
+                            />
                             <op id="R-start-interval-0s" interval="0s"
                                 name="start" timeout="20"
                             />
@@ -834,9 +883,18 @@ class SuccessClone(ResourceTest):
                         type="Dummy"
                     >
                         <operations>
+                            <op id="R-migrate_from-interval-0s" interval="0s"
+                                name="migrate_from" timeout="20"
+                            />
+                            <op id="R-migrate_to-interval-0s" interval="0s"
+                                name="migrate_to" timeout="20"
+                            />
                             <op id="R-monitor-interval-10" interval="10"
                                 name="monitor"
                             />
+                            <op id="R-reload-interval-0s" interval="0s"
+                                name="reload" timeout="20"
+                            />
                             <op id="R-start-interval-0s" interval="0s"
                                 name="start" timeout="20"
                             />
@@ -868,9 +926,18 @@ class SuccessClone(ResourceTest):
                         type="Dummy"
                     >
                         <operations>
+                            <op id="R-migrate_from-interval-0s" interval="0s"
+                                name="migrate_from" timeout="20"
+                            />
+                            <op id="R-migrate_to-interval-0s" interval="0s"
+                                name="migrate_to" timeout="20"
+                            />
                             <op id="R-monitor-interval-10" interval="10"
                                 name="monitor" timeout="20"
                             />
+                            <op id="R-reload-interval-0s" interval="0s"
+                                name="reload" timeout="20"
+                            />
                             <op id="R-start-interval-0s" interval="0s"
                                 name="start" timeout="20"
                             />
@@ -918,7 +985,7 @@ class Bundle(ResourceTest):
         self.fixture_primitive("R1")
         self.assert_pcs_fail(
             "resource create R2 ocf:heartbeat:Dummy bundle R1",
-            "Error: 'R1' is not bundle\n"
+            "Error: 'R1' is not a bundle\n"
         )
 
     def test_bundle_id_does_not_exist(self):
@@ -1019,10 +1086,14 @@ class FailOrWarn(ResourceTest):
     def test_fail_when_nonexisting_agent(self):
         self.assert_pcs_fail(
             "resource create R ocf:heartbeat:NoExisting",
-            "Error: Agent 'ocf:heartbeat:NoExisting' is not installed or does"
-                " not provide valid metadata: Metadata query for"
-                " ocf:heartbeat:NoExisting failed: -5, use --force to"
-                " override\n"
+            # pacemaker 1.1.18 changes -5 to Input/output error
+            stdout_regexp=re.compile("^"
+                "Error: Agent 'ocf:heartbeat:NoExisting' is not installed or "
+                "does not provide valid metadata: Metadata query for "
+                "ocf:heartbeat:NoExisting failed: (-5|Input/output error), use "
+                "--force to override\n"
+                "$", re.MULTILINE
+            )
         )
 
     def test_warn_when_forcing_noexistent_agent(self):
@@ -1039,9 +1110,13 @@ class FailOrWarn(ResourceTest):
                     </operations>
                 </primitive>
             </resources>""",
-            "Warning: Agent 'ocf:heartbeat:NoExisting' is not installed or does"
-            " not provide valid metadata: Metadata query for"
-            " ocf:heartbeat:NoExisting failed: -5\n"
+            # pacemaker 1.1.18 changes -5 to Input/output error
+            output_regexp=re.compile("^"
+                "Warning: Agent 'ocf:heartbeat:NoExisting' is not installed or "
+                    "does not provide valid metadata: Metadata query for "
+                    "ocf:heartbeat:NoExisting failed: (-5|Input/output error)\n"
+                "$", re.MULTILINE
+            )
         )
 
 
