@@ -2,24 +2,23 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 import shutil
 from pcs.test.tools import pcs_unittest as unittest
 
-from pcs.test.tools.assertions import AssertPcsMixin
-from pcs.test.tools.misc import (
+from pcs.test.tools.assertions import (
     ac,
-    get_test_resource as rc,
+    AssertPcsMixin,
 )
+from pcs.test.tools.misc import get_test_resource as rc
 from pcs.test.tools.pcs_runner import (
     pcs,
     PcsRunner,
 )
 
-old_cib = rc("cib-empty.xml")
-empty_cib = rc("cib-empty-1.2.xml")
+old_cib = rc("cib-empty-1.2.xml")
+empty_cib = rc("cib-empty.xml")
 temp_cib = rc("temp-cib.xml")
 
 class ACLTest(unittest.TestCase, AssertPcsMixin):
@@ -33,17 +32,8 @@ class ACLTest(unittest.TestCase, AssertPcsMixin):
 
         self.assert_pcs_success(
             'acl show',
-            "ACLs are disabled, run 'pcs acl enable' to enable\n\n"
-        )
-
-        with open(temp_cib) as myfile:
-            data = myfile.read()
-            assert data.find("pacemaker-1.2") != -1
-            assert data.find("pacemaker-2.") == -1
-
-        self.assert_pcs_success(
-            'acl role create test_role read xpath my_xpath',
-            "CIB has been upgraded to the latest schema version.\n"
+            "ACLs are disabled, run 'pcs acl enable' to enable"
+            "\n\nCIB has been upgraded to the latest schema version.\n"
         )
 
         with open(temp_cib) as myfile:
@@ -90,19 +80,19 @@ class ACLTest(unittest.TestCase, AssertPcsMixin):
         ac(o,"")
 
         o, r = pcs("acl user create user1 roleX")
-        ac(o, "Error: role 'roleX' does not exist\n")
+        ac(o, "Error: ACL role 'roleX' does not exist\n")
         self.assertEqual(1, r)
 
         o, r = pcs("acl user create user1 role1 roleX")
-        ac(o, "Error: role 'roleX' does not exist\n")
+        ac(o, "Error: ACL role 'roleX' does not exist\n")
         self.assertEqual(1, r)
 
         o, r = pcs("acl group create group1 roleX")
-        ac(o, "Error: role 'roleX' does not exist\n")
+        ac(o, "Error: ACL role 'roleX' does not exist\n")
         self.assertEqual(1, r)
 
         o, r = pcs("acl group create group1 role1 roleX")
-        ac(o, "Error: role 'roleX' does not exist\n")
+        ac(o, "Error: ACL role 'roleX' does not exist\n")
         self.assertEqual(1, r)
 
         o, r = pcs("acl")
@@ -174,11 +164,11 @@ Role: role3
 
         o,r = pcs("acl role assign role1 to noexist")
         assert r == 1
-        ac(o,"Error: user/group 'noexist' does not exist\n")
+        ac(o,"Error: ACL group/ACL user 'noexist' does not exist\n")
 
         o,r = pcs("acl role assign noexist to user1")
         assert r == 1
-        ac(o,"Error: role 'noexist' does not exist\n")
+        ac(o,"Error: ACL role 'noexist' does not exist\n")
 
         o,r = pcs("acl role assign role3 to user1")
         assert r == 0
@@ -194,7 +184,7 @@ Role: role3
 
         o,r = pcs("acl role unassign role3 from noexist")
         assert r == 1
-        ac(o,"Error: user/group 'noexist' does not exist\n")
+        ac(o,"Error: ACL group/ACL user 'noexist' does not exist\n")
 
         o,r = pcs("acl role unassign role3 from user1")
         assert r == 0
@@ -405,7 +395,7 @@ Group: group2
 
         o,r = pcs("acl group delete user1")
         assert r == 1
-        ac(o,"Error: group 'user1' does not exist\n")
+        ac(o,"Error: 'user1' is not an ACL group\n")
 
         o,r = pcs("acl")
         ac(o, """\
@@ -594,7 +584,7 @@ User: user2
 
         o,r = pcs("acl role delete role2")
         assert r == 1
-        ac(o,"Error: role 'role2' does not exist\n")
+        ac(o,"Error: ACL role 'role2' does not exist\n")
 
         o,r = pcs("acl role delete role1")
         assert r == 0
@@ -650,7 +640,7 @@ User: user2
         assert r == 0
 
         o,r = pcs("acl permission delete role4-deny")
-        ac(o,"Error: permission 'role4-deny' does not exist\n")
+        ac(o,"Error: ACL permission 'role4-deny' does not exist\n")
         assert r == 1
 
         o,r = pcs("acl show")
@@ -835,7 +825,7 @@ Role: role4
         self.assert_pcs_success("acl group create group1")
         self.assert_pcs_fail(
             "acl role assign role1 to user group1",
-            "Error: user 'group1' does not exist\n"
+            "Error: 'group1' is not an ACL user\n"
         )
 
     def test_assign_unassign_role_to_user_with_to(self):
@@ -871,7 +861,7 @@ Role: role4
         self.assert_pcs_success("acl user create user1")
         self.assert_pcs_fail(
             "acl role assign role1 to group user1",
-            "Error: group 'user1' does not exist\n"
+            "Error: 'user1' is not an ACL group\n"
         )
 
     def test_assign_unassign_role_to_group_with_to(self):
@@ -887,4 +877,3 @@ Role: role4
             "acl role unassign role1 from group group1",
             "Error: Role 'role1' is not assigned to 'group1'\n"
         )
-
