@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 import os
@@ -10,11 +9,14 @@ import shutil
 import socket
 from pcs.test.tools import pcs_unittest as unittest
 
-from pcs.test.tools.assertions import AssertPcsMixin
-from pcs.test.tools.misc import (
+from pcs.test.tools.assertions import (
     ac,
+    AssertPcsMixin,
+)
+from pcs.test.tools.misc import (
     get_test_resource as rc,
     skip_unless_pacemaker_version,
+    skip_if_service_enabled,
     outdent,
 )
 from pcs.test.tools.pcs_runner import (
@@ -523,6 +525,7 @@ logging {
         )
         self.assertEqual(1, returnVal)
 
+    @skip_if_service_enabled("sbd")
     def test_cluster_setup_2_nodes_no_atb(self):
         # Setup a 2 node cluster and make sure the two node config is set, then
         # add a node and make sure that it's unset, then remove a node and make
@@ -2758,26 +2761,6 @@ Warning: --token_coefficient ignored as it is not supported on CMAN clusters
             assert r == 0
             ac(o, "No uidgids configured in cluster.conf\n")
 
-    @skip_unless_pacemaker_version((1, 1, 11), "CIB schema upgrade")
-    def testClusterUpgrade(self):
-        with open(temp_cib) as myfile:
-            data = myfile.read()
-            assert data.find("pacemaker-1.2") != -1
-            assert data.find("pacemaker-2.") == -1
-
-        o,r = pcs("cluster cib-upgrade")
-        ac(o,"Cluster CIB has been upgraded to latest version\n")
-        assert r == 0
-
-        with open(temp_cib) as myfile:
-            data = myfile.read()
-            assert data.find("pacemaker-1.2") == -1
-            assert data.find("pacemaker-2.") != -1
-
-        o,r = pcs("cluster cib-upgrade")
-        ac(o,"Cluster CIB has been upgraded to latest version\n")
-        assert r == 0
-
     def test_can_not_setup_cluster_for_unknown_transport_type(self):
         if utils.is_rhel6():
             return
@@ -2989,6 +2972,33 @@ logging {
 """)
 
 
+class ClusterUpgradeTest(unittest.TestCase, AssertPcsMixin):
+    def setUp(self):
+        shutil.copy(rc("cib-empty-1.2.xml"), temp_cib)
+        self.pcs_runner = PcsRunner(temp_cib)
+
+    @skip_unless_pacemaker_version((1, 1, 11), "CIB schema upgrade")
+    def testClusterUpgrade(self):
+        with open(temp_cib) as myfile:
+            data = myfile.read()
+            assert data.find("pacemaker-1.2") != -1
+            assert data.find("pacemaker-2.") == -1
+
+        o,r = pcs("cluster cib-upgrade")
+        ac(o,"Cluster CIB has been upgraded to latest version\n")
+        assert r == 0
+
+        with open(temp_cib) as myfile:
+            data = myfile.read()
+            assert data.find("pacemaker-1.2") == -1
+            assert data.find("pacemaker-2.") != -1
+
+        o,r = pcs("cluster cib-upgrade")
+        ac(o,"Cluster CIB has been upgraded to latest version\n")
+        assert r == 0
+
+
+
 class ClusterStartStop(unittest.TestCase, AssertPcsMixin):
     def setUp(self):
         self.pcs_runner = PcsRunner()
