@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 from pcs.test.cib_resource.common import ResourceTest
@@ -69,9 +68,18 @@ class NodeAddRemote(ResourceTest):
                         />
                     </instance_attributes>
                     <operations>
+                        <op id="node-name-migrate_from-interval-0s"
+                            interval="0s" name="migrate_from" timeout="60"
+                        />
+                        <op id="node-name-migrate_to-interval-0s" interval="0s"
+                            name="migrate_to" timeout="60"
+                        />
                         <op id="node-name-monitor-interval-60s" interval="60s"
                             name="monitor" timeout="30"
                         />
+                        <op id="node-name-reload-interval-0s" interval="0s"
+                            name="reload" timeout="60"
+                        />
                         <op id="node-name-start-interval-0s" interval="0s"
                             name="start" timeout="60"
                         />
@@ -169,7 +177,7 @@ class NodeAddGuest(ResourceTest):
     def test_fail_when_resource_does_not_exists(self):
         self.assert_pcs_fail(
             "cluster node add-guest some-host non-existent",
-            "Error: primitive 'non-existent' does not exist\n"
+            "Error: resource 'non-existent' does not exist\n"
         )
 
     def test_fail_when_option_remote_node_specified(self):
@@ -199,7 +207,7 @@ class NodeAddGuest(ResourceTest):
             "cluster node add-guest node-host G a=b",
             "Error: invalid guest option 'a', allowed options are:"
                 " remote-addr, remote-connect-timeout, remote-port\n"
-                "Error: primitive 'G' does not exist\n"
+                "Error: resource 'G' does not exist\n"
         )
 
     def test_fail_when_disallowed_option_appear(self):
@@ -291,6 +299,19 @@ class NodeAddGuest(ResourceTest):
             output=fixture_nolive_add_report
         )
 
+    def test_success_when_guest_node_matches_with_existing_guest(self):
+        # This test belongs to pcs/test/test_resource.py as it tests
+        # "resource update". But due to some fixtures it is more practical to
+        # keep it here.
+        self.create_resource()
+        self.assert_pcs_success(
+            "cluster node add-guest node-host G",
+            fixture_nolive_add_report
+        )
+        self.assert_pcs_success(
+            "resource update G meta remote-node=node-host",
+        )
+
     def test_success_with_options(self):
         self.create_resource()
         self.assert_effect(
