@@ -2,12 +2,11 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 from pcs.test.tools import pcs_unittest as unittest
 
-from pcs.test.tools.misc import ac
+from pcs.test.tools.assertions import ac
 
 from pcs.lib.corosync import config_parser
 
