@@ -2,7 +2,6 @@ from __future__ import (
     absolute_import,
     division,
     print_function,
-    unicode_literals,
 )
 
 import re
@@ -158,9 +157,13 @@ Options:
     -h, --help         Display usage and exit.
     -f file            Perform actions on file instead of active CIB.
     --debug            Print all network traffic and external commands run.
-    --version          Print pcs version information.
+    --version          Print pcs version information. List pcs capabilities if
+                       --full is specified.
     --request-timeout  Timeout for each outgoing request to another node in
                        seconds. Default is 60s.
+    --force            Override checks and errors, the exact behavior depends on
+                       the command. WARNING: Using the --force option is
+                       strongly discouraged unless you know what you are doing.
 
 Commands:
     cluster     Configure cluster options and nodes.
@@ -471,13 +474,23 @@ Commands:
         override them with their own defined values.
 
     cleanup [<resource id>] [--node <node>]
-        Make the cluster forget the operation history of the resource and
-        re-detect its current state. This can be useful to purge knowledge of
-        past failures that have since been resolved. If a resource id is not
-        specified then all resources/stonith devices will be cleaned up. If a
-        node is not specified then resources/stonith devices on all nodes will
+        Make the cluster forget failed operations from history of the resource
+        and re-detect its current state. This can be useful to purge knowledge
+        of past failures that have since been resolved. If a resource id is not
+        specified then all resources / stonith devices will be cleaned up. If a
+        node is not specified then resources / stonith devices on all nodes will
         be cleaned up.
 
+    refresh [<resource id>] [--node <node>] [--full]
+        Make the cluster forget the complete operation history (including
+        failures) of the resource and re-detect its current state. If you are
+        interested in forgetting failed operations only, use the 'pcs resource
+        cleanup' command. If a resource id is not specified then all resources
+        / stonith devices will be refreshed. If a node is not specified then
+        resources / stonith devices on all nodes will be refreshed. Use --full
+        to refresh a resource on all nodes, otherwise only nodes where the
+        resource's state is known will be considered.
+
     failcount show <resource id> [node]
         Show current failcount for specified resource from all nodes or
         only on specified node.
@@ -561,7 +574,8 @@ Usage: pcs cluster [commands]...
 Configure cluster for use with pacemaker
 
 Commands:
-    auth [node] [...] [-u username] [-p password] [--force] [--local]
+    auth [<node>[:<port>]] [...] [-u <username>] [-p <password>] [--force]
+            [--local]
         Authenticate pcs to pcsd on nodes specified, or on all nodes
         configured in the local cluster if no nodes are specified (authorization
         tokens are stored in ~/.pcs/tokens or /var/lib/pcsd/tokens for root).
@@ -600,7 +614,8 @@ Commands:
         --ipv6 will configure corosync to use ipv6 (instead of ipv4). This
             option is not supported on CMAN clusters.
         --token <timeout> sets time in milliseconds until a token loss is
-            declared after not receiving a token (default 1000 ms)
+            declared after not receiving a token (default 1000 ms;
+            10000 ms for CMAN clusters)
         --token_coefficient <timeout> sets time in milliseconds used for
             clusters with at least 3 nodes as a coefficient for real token
             timeout calculation
@@ -636,20 +651,22 @@ Commands:
         ttl defaults to 1. If --broadcast is specified, --mcast0/1,
         --mcastport0/1 & --ttl0/1 are ignored.
 
-    start [--all | <node>... ] [--wait[=<n>]]
-        Start corosync & pacemaker on specified node(s), if a node is not
-        specified then corosync & pacemaker are started on the local node.
-        If --all is specified then corosync & pacemaker are started on all
-        nodes.  If --wait is specified, wait up to 'n' seconds for nodes
-        to start.
+    start [--all | <node>... ] [--wait[=<n>]] [--request-timeout=<seconds>]
+        Start a cluster on specified node(s). If no nodes are specified then
+        start a cluster on the local node. If --all is specified then start
+        a cluster on all nodes. If the cluster has many nodes then the start
+        request may time out. In that case you should consider setting
+        --request-timeout to a suitable value. If --wait is specified, pcs
+        waits up to 'n' seconds for the cluster to get ready to provide
+        services after the cluster has successfully started.
 
     stop [--all | <node>... ] [--request-timeout=<seconds>]
-        Stop corosync & pacemaker on specified node(s), if a node is not
-        specified then corosync & pacemaker are stopped on the local node. If
-        --all is specified then corosync & pacemaker are stopped on all nodes.
-        If the cluster is running resources which take long time to stop, the
-        request may time out before the cluster actually stops. In that case you
-        should consider setting --request-timeout to a suitable value.
+        Stop a cluster on specified node(s). If no nodes are specified then
+        stop a cluster on the local node. If --all is specified then stop
+        a cluster on all nodes. If the cluster is running resources which take
+        long time to stop then the stop request may time out before the cluster
+        actually stops. In that case you should consider setting
+        --request-timeout to a suitable value.
 
     kill
         Force corosync and pacemaker daemons to stop on the local node
@@ -805,7 +822,7 @@ Commands:
         performed on the currently running cluster.  If -V is used
         more verbose output will be printed.
 
-    report [--from "YYYY-M-D H:M:S" [--to "YYYY-M-D H:M:S"]] dest
+    report [--from "YYYY-M-D H:M:S" [--to "YYYY-M-D H:M:S"]] <dest>
         Create a tarball containing everything needed when reporting cluster
         problems.  If --from and --to are not used, the report will include
         the past 24 hours.
@@ -857,26 +874,38 @@ Commands:
     delete <stonith id>
         Remove stonith id from configuration.
 
-    enable <stonith id> [--wait[=n]]
-        Allow the cluster to use the stonith device. If --wait is specified, pcs
-        will wait up to 'n' seconds for the stonith device to start and then
-        return 0 if the stonith device is started, or 1 if the stonith device
-        has not yet started. If 'n' is not specified it defaults to 60 minutes.
+    enable <stonith id>... [--wait[=n]]
+        Allow the cluster to use the stonith devices. If --wait is specified,
+        pcs will wait up to 'n' seconds for the stonith devices to start and
+        then return 0 if the stonith devices are started, or 1 if the stonith
+        devices have not yet started. If 'n' is not specified it defaults to 60
+        minutes.
 
-    disable <stonith id> [--wait[=n]]
-        Attempt to stop the stonith device if it is running and disallow the
-        cluster to use it. If --wait is specified, pcs will wait up to 'n'
-        seconds for the stonith device to stop and then return 0 if the stonith
-        device is stopped or 1 if the stonith device has not stopped.  If 'n' is
-        not specified it defaults to 60 minutes.
+    disable <stonith id>... [--wait[=n]]
+        Attempt to stop the stonith devices if they are running and disallow
+        the cluster to use them. If --wait is specified, pcs will wait up to
+        'n' seconds for the stonith devices to stop and then return 0 if the
+        stonith devices are stopped or 1 if the stonith devices have not
+        stopped. If 'n' is not specified it defaults to 60 minutes.
 
     cleanup [<stonith id>] [--node <node>]
-        Make the cluster forget the operation history of the stonith device and
-        re-detect its current state. This can be useful to purge knowledge of
-        past failures that have since been resolved. If a stonith id is not
-        specified then all resources/stonith devices will be cleaned up. If a
-        node is not specified then resources/stonith devices on all nodes will
-        be cleaned up.
+        Make the cluster forget failed operations from history of the stonith
+        device and re-detect its current state. This can be useful to purge
+        knowledge of past failures that have since been resolved. If a stonith
+        id is not specified then all resources / stonith devices will be cleaned
+        up. If a node is not specified then resources / stonith devices on all
+        nodes will be cleaned up.
+
+    refresh [<stonith id>] [--node <node>] [--full]
+        Make the cluster forget the complete operation history (including
+        failures) of the stonith device and re-detect its current state. If you
+        are interested in forgetting failed operations only, use the 'pcs
+        stonith cleanup' command. If a stonith id is not specified then all
+        resources / stonith devices will be refreshed. If a node is not
+        specified then resources / stonith devices on all nodes will be
+        refreshed. Use --full to refresh a stonith device on all nodes,
+        otherwise only nodes where the stonith device's state is known will be
+        considered.
 
     level [config]
         Lists all of the fencing levels currently configured.
@@ -916,9 +945,11 @@ Commands:
         call to stonith which will turn the node off instead of rebooting it).
 
     confirm <node> [--force]
-        Confirm that the host specified is currently down.  This command
-        should ONLY be used when the node specified has already been confirmed
-        to be powered off and to have no access to shared resources.
+        Confirm to the cluster that the specified node is powered off. This
+        allows the cluster to recover from a situation where no stonith device
+        is able to fence the node. This command should ONLY be used after
+        manually ensuring that the node is powered off and has no access to
+        shared resources.
 
         WARNING: If this node is not actually powered off or it does have
         access to shared resources, data corruption/cluster failure can occur.
@@ -1280,6 +1311,9 @@ Commands:
         --full will give more detailed output.  If <cluster name> is specified,
         only information about the specified cluster will be displayed.
 
+    booth
+        Print current status of booth on the local node.
+
     nodes [corosync | both | config]
         View current status of nodes from pacemaker. If 'corosync' is
         specified, view current status of nodes from corosync instead. If
@@ -1518,11 +1552,16 @@ Commands:
         Show quorum runtime status.
 
     device add [<generic options>] model <device model> [<model options>]
+            [heuristics <heuristics options>]
         Add a quorum device to the cluster. Quorum device needs to be created
         first by "pcs qdevice setup" command. It is not possible to use more
-        than one quorum device in a cluster simultaneously. Generic options,
-        model and model options are all documented in corosync-qdevice(8) man
-        page.
+        than one quorum device in a cluster simultaneously. Models and options
+        are all documented in corosync-qdevice(8) man page; for heuristics
+        options check the quorum.device.heuristics subkey section, for model
+        options check the quorum.device.<device model> subkey sections.
+
+    device heuristics remove
+        Remove all heuristics settings of the configured quorum device.
 
     device remove
         Remove a quorum device from the cluster.
@@ -1532,9 +1571,12 @@ Commands:
         output.
 
     device update [<generic options>] [model <model options>]
-        Add/Change quorum device options. Generic options and model options are
-        all documented in corosync-qdevice(8) man page. Requires the cluster to
-        be stopped.
+            [heuristics <heuristics options>]
+        Add/Change quorum device options. Requires the cluster to be stopped.
+        Model and options are all documented in corosync-qdevice(8) man page;
+        for heuristics options check the quorum.device.heuristics subkey
+        section, for model options check the quorum.device.<device model> subkey
+        sections.
 
         WARNING: If you want to change "host" option of qdevice model net, use
         "pcs quorum device remove" and "pcs quorum device add" commands
