@@ -88,7 +88,7 @@ except ImportError:
     from urllib.parse import urlencode as urllib_urlencode
 
 
-PYTHON2 = sys.version[0] == "2"
+PYTHON2 = (sys.version_info.major == 2)
 
 # usefile & filename variables are set in pcs module
 usefile = False
@@ -973,7 +973,9 @@ def touch_cib_file(filename):
         try:
             write_empty_cib(filename)
         except EnvironmentError as e:
-           err("Unable to write to file: '{0}': '{1}'".format(filename, str(e)))
+            err(
+                "Unable to write to file: '{0}': '{1}'".format(filename, str(e))
+            )
 
 # Run command, with environment and return (output, retval)
 # DEPRECATED, please use lib.external.CommandRunner via utils.cmd_runner()
@@ -1449,11 +1451,7 @@ def validate_constraint_resource(dom, resource_id):
         return True, "", resource_id
 
     if "--force" in pcs_options:
-        return (
-            True,
-            "",
-            clone_el.getAttribute("id") if clone_el else resource_id
-        )
+        return True, "", clone_el.getAttribute("id")
 
     if clone_el.tagName == "clone":
         return (
@@ -2831,7 +2829,7 @@ def get_library_wrapper():
     return Library(get_cli_env(), get_middleware_factory())
 
 
-def get_modificators():
+def get_modifiers():
     #please keep in mind that this is not final implemetation
     #beside missing support of other possible options, cases may arise that can
     #not be solved using a dict - for example "wait" - maybe there will be
