@@ -25,21 +25,23 @@ end
 
 def is_systemctl()
   systemctl_paths = [
-      '/usr/bin/systemctl',
-      '/bin/systemctl',
-      '/var/run/systemd/system',
       '/run/systemd/system',
+      '/var/run/systemd/system',
   ]
   systemctl_paths.each { |path|
-    return true if File.exist?(path)
+    return true if File.directory?(path)
   }
   return false
 end
 
-def get_pcs_path()
-  pcsd_path = Pathname.new(
+def get_pcsd_path()
+  return Pathname.new(
       File.expand_path(File.dirname(__FILE__))
-    ).realpath.to_s
+    ).realpath
+end
+
+def get_pcs_path()
+  pcsd_path = get_pcsd_path().to_s
   if PCSD_EXEC_LOCATION == pcsd_path or PCSD_EXEC_LOCATION == (pcsd_path + '/')
     return PCS_EXEC
   else
@@ -47,7 +49,7 @@ def get_pcs_path()
   end
 end
 
-PCS_VERSION = '0.9.159'
+PCS_VERSION = '0.9.164'
 # unique instance signature, allows detection of dameon restarts
 DAEMON_INSTANCE_SIGNATURE = Digest::SHA2.hexdigest("#{Time.now} #{rand()}")
 COROSYNC = COROSYNC_BINARIES + "corosync"
@@ -78,6 +80,42 @@ def configure_logger(log_device)
   else
     logger.debug "Did not detect RHEL 6"
   end
+
+  if ISSYSTEMCTL
+    logger.debug "Detected systemd is in use"
+  else
+    logger.debug "Detected systemd is not in use"
+  end
   return logger
 end
 
+def get_capabilities(logger)
+  capabilities = []
+  capabilities_pcsd = []
+  begin
+    filename = (get_pcsd_path() + Pathname.new('capabilities.xml')).to_s
+    capabilities_xml = REXML::Document.new(File.new(filename))
+    capabilities_xml.elements.each('.//capability') { |feat_xml|
+      feat = {}
+      feat_xml.attributes.each() { |name, value|
+        feat[name] = value
+      }
+      feat['description'] = ''
+      if feat_xml.elements['description']
+        feat['description'] = feat_xml.elements['description'].text.strip
+      end
+      capabilities << feat
+    }
+    capabilities.each { |feat|
+      if feat['in-pcsd'] == '1'
+        capabilities_pcsd << feat['id']
+      end
+    }
+  rescue => e
+    logger.error(
+      "Cannot read capabilities definition file '#{filename}': '#{e}'"
+    )
+    return [], []
+  end
+  return capabilities, capabilities_pcsd
+end
