@@ -401,18 +401,24 @@ def send_nodes_request_with_token(auth_user, nodes, request, post=false, data={}
   return code, out
 end
 
-def send_request_with_token(auth_user, node, request, post=false, data={}, remote=true, raw_data=nil, timeout=nil, additional_tokens={})
-  token = additional_tokens[node] || get_node_token(node)
+def send_request_with_token(
+  auth_user, node, request, post=false, data={}, remote=true, raw_data=nil,
+  timeout=nil, additional_tokens={}, additional_ports={}
+)
+  token_file_data = read_token_file()
+  token = additional_tokens[node] || token_file_data.tokens[node]
   $logger.info "SRWT Node: #{node} Request: #{request}"
   if not token
     $logger.error "Unable to connect to node #{node}, no token available"
     return 400,'{"notoken":true}'
   end
+  port = additional_ports[node] || token_file_data.ports[node]
   cookies_data = {
     'token' => token,
   }
   return send_request(
-    auth_user, node, request, post, data, remote, raw_data, timeout, cookies_data
+    auth_user, node, request, post, data, remote, raw_data, timeout,
+    cookies_data, port
   )
 end
 
@@ -455,7 +461,7 @@ end
 
 def send_request(
   auth_user, node, request, post=false, data={}, remote=true, raw_data=nil,
-  timeout=nil, cookies_data=nil
+  timeout=nil, cookies_data=nil, port=nil
 )
   cookies_data = {} if not cookies_data
   if request.start_with?("/")
@@ -467,10 +473,12 @@ def send_request(
     node6 = "[#{node}]"
   end
 
+  port ||= PCSD_DEFAULT_PORT
+
   if remote
-    url = "https://#{node6}:2224/remote/#{request}"
+    url = "https://#{node6}:#{port}/remote/#{request}"
   else
-    url = "https://#{node6}:2224/#{request}"
+    url = "https://#{node6}:#{port}/#{request}"
   end
 
   data = _transform_data(data)
@@ -1103,13 +1111,21 @@ def is_cib_true(var)
   return ['true', 'on', 'yes', 'y', '1'].include?(var.downcase)
 end
 
+def read_token_file()
+  return PCSTokens.new(Cfgsync::PcsdTokens.from_file().text())
+end
+
 def read_tokens()
-  return PCSTokens.new(Cfgsync::PcsdTokens.from_file().text()).tokens
+  return read_token_file().tokens
+end
+
+def get_nodes_ports()
+  return read_token_file().ports
 end
 
 def write_tokens(tokens)
   begin
-    cfg = PCSTokens.new(Cfgsync::PcsdTokens.from_file().text())
+    cfg = read_token_file()
     cfg.tokens = tokens
     Cfgsync::PcsdTokens.from_text(cfg.text()).save()
   rescue
@@ -1149,16 +1165,21 @@ def add_prefix_to_keys(hash, prefix)
   return new_hash
 end
 
-def check_gui_status_of_nodes(auth_user, nodes, check_mutuality=false, timeout=10)
+def check_gui_status_of_nodes(auth_user, nodes, check_mutuality=false, timeout=10, ports=nil)
   options = {}
   options[:check_auth_only] = '' if not check_mutuality
   threads = []
   not_authorized_nodes = []
   online_nodes = []
   offline_nodes = []
+  token_file = read_token_file()
 
   nodes = nodes.uniq.sort
   nodes.each { |node|
+    if ports and ports[node] != token_file.ports[node]
+      not_authorized_nodes << node
+      next
+    end
     threads << Thread.new {
       code, response = send_request_with_token(
         auth_user, node, 'check_auth', false, options, true, nil, timeout
@@ -1187,6 +1208,7 @@ def check_gui_status_of_nodes(auth_user, nodes, check_mutuality=false, timeout=1
             offline_nodes << node
           end
         rescue JSON::ParserError
+          not_authorized_nodes << node
         end
       end
     }
@@ -1196,6 +1218,7 @@ def check_gui_status_of_nodes(auth_user, nodes, check_mutuality=false, timeout=1
 end
 
 def pcs_auth(auth_user, nodes, username, password, force=false, local=true)
+  # nodes is hash, (nodename -> port)
   # if no sync is needed, do not report a sync error
   sync_successful = true
   sync_failed_nodes = []
@@ -1203,7 +1226,7 @@ def pcs_auth(auth_user, nodes, username, password, force=false, local=true)
   # check for already authorized nodes
   if not force
     online, offline, not_authenticated = check_gui_status_of_nodes(
-      auth_user, nodes, true
+      auth_user, nodes.keys, true, 10, nodes
     )
     if not_authenticated.length < 1
       result = {}
@@ -1220,25 +1243,28 @@ def pcs_auth(auth_user, nodes, username, password, force=false, local=true)
 
   # get the tokens and sync them within the local cluster
   new_tokens = {}
+  ports = {}
   auth_responses.each { |node, response|
-    new_tokens[node] = response['token'] if 'ok' == response['status']
+    if 'ok' == response['status']
+      new_tokens[node] = response['token']
+      ports[node] = nodes[node] || PCSD_DEFAULT_PORT
+    end
   }
   if not new_tokens.empty?
-    cluster_nodes = get_corosync_nodes()
     tokens_cfg = Cfgsync::PcsdTokens.from_file()
     # only tokens used in pcsd-to-pcsd communication can and need to be synced
     # those are accessible only when running under root account
     if Process.uid != 0
       # other tokens just need to be stored localy for the user
       sync_successful, sync_responses = Cfgsync::save_sync_new_tokens(
-        tokens_cfg, new_tokens, [], nil
+        tokens_cfg, new_tokens, [], nil, ports
       )
       return auth_responses, sync_successful, sync_failed_nodes, sync_responses
     end
+    cluster_nodes = get_corosync_nodes()
     sync_successful, sync_responses = Cfgsync::save_sync_new_tokens(
-      tokens_cfg, new_tokens, cluster_nodes, $cluster_name
+      tokens_cfg, new_tokens, cluster_nodes, $cluster_name, ports
     )
-    sync_failed_nodes = []
     sync_not_supported_nodes = []
     sync_responses.each { |node, response|
       if 'not_supported' == response['status']
@@ -1257,10 +1283,10 @@ def pcs_auth(auth_user, nodes, username, password, force=false, local=true)
     if not local
       # authorize nodes outside of the local cluster and nodes not supporting
       # the tokens file synchronization in the other direction
-      nodes_to_auth = []
-      nodes.each { |node|
-        nodes_to_auth << node if sync_not_supported_nodes.include?(node)
-        nodes_to_auth << node if not cluster_nodes.include?(node)
+      nodes_to_auth = {}
+      nodes.each { |node, port|
+        nodes_to_auth[node] = port if sync_not_supported_nodes.include?(node)
+        nodes_to_auth[node] = port if not cluster_nodes.include?(node)
       }
       auth_responses2 = run_auth_requests(
         auth_user, nodes_to_auth, nodes, username, password, force, false
@@ -1274,8 +1300,11 @@ end
 
 def run_auth_requests(auth_user, nodes_to_send, nodes_to_auth, username, password, force=false, local=true)
   data = {}
-  nodes_to_auth.each_with_index { |node, index|
+  index = 0
+  nodes_to_auth.each { |node, port|
     data["node-#{index}"] = node
+    data["port-#{node}"] = port if port
+    index += 1
   }
   data['username'] = username
   data['password'] = password
@@ -1284,9 +1313,11 @@ def run_auth_requests(auth_user, nodes_to_send, nodes_to_auth, username, passwor
 
   auth_responses = {}
   threads = []
-  nodes_to_send.each { |node|
+  nodes_to_send.each { |node, port|
     threads << Thread.new {
-      code, response = send_request(auth_user, node, 'auth', true, data)
+      code, response = send_request(
+        auth_user, node, 'auth', true, data, true, nil, nil, nil, port
+      )
       if 200 == code
         token = response.strip
         if '' == token
@@ -1562,7 +1593,10 @@ def cluster_status_from_nodes(auth_user, cluster_nodes, cluster_name)
     :status => 'unknown',
     :node_list => [],
     :resource_list => [],
+    # deprecated, kept for backward compatibility
+    # use pcsd_capabilities instead
     :available_features => [],
+    :pcsd_capabilities => [],
   }
 
   threads = []
@@ -1592,6 +1626,7 @@ def cluster_status_from_nodes(auth_user, cluster_nodes, cluster_name)
       begin
         parsed_response = JSON.parse(response, {:symbolize_names => true})
         parsed_response[:available_features] ||= []
+        parsed_response[:pcsd_capabilities] ||= []
         if parsed_response[:noresponse]
           node_map[node][:node] = {}
           node_map[node][:node].update(node_status_unknown)
@@ -1682,11 +1717,15 @@ def cluster_status_from_nodes(auth_user, cluster_nodes, cluster_name)
   node_map.each { |_, cluster_status|
     node_status = cluster_status[:node][:status]
     node_name = cluster_status[:node][:name]
-    # create set of available features on all nodes
-    # it is intersection of available features from all nodes
+    # Create a set of available features on all nodes as an intersection of
+    # available features from all nodes. Do it for both the old deprecated list
+    # (available_features) and the new one (pcsd_capabilities)
     if node_status != 'unknown' and cluster_status[:available_features]
       status[:available_features] &= cluster_status[:available_features]
     end
+    if node_status != 'unknown' and cluster_status[:pcsd_capabilities]
+      status[:pcsd_capabilities] &= cluster_status[:pcsd_capabilities]
+    end
     if (
       cluster_status[:node][:services] and
       cluster_status[:node][:services][:sbd]
@@ -1768,7 +1807,7 @@ def cluster_status_from_nodes(auth_user, cluster_nodes, cluster_name)
         :message => 'Unable to connect to the cluster.'
       }
     end
-    status[:status] == 'unknown'
+    status[:status] = 'unknown'
     return status
   end
 
@@ -1829,6 +1868,8 @@ def get_node_status(auth_user, cib_dom)
       :nodes_utilization => get_nodes_utilization(cib_dom),
       :alerts => get_alerts(auth_user),
       :known_nodes => [],
+      # deprecated, kept for backward compatibility
+      # use pcsd_capabilities instead
       :available_features => [
         'constraint_colocation_set',
         'sbd',
@@ -1837,7 +1878,8 @@ def get_node_status(auth_user, cib_dom)
         'unmanaged_resource',
         'alerts',
         'hardened_cluster',
-      ]
+      ],
+      :pcsd_capabilities => CAPABILITIES_PCSD
   }
 
   nodes = get_nodes_status()
