@@ -132,11 +132,14 @@ $thread_cfgsync = Thread.new {
         begin
           # do not sync if this host is not in a cluster
           cluster_name = get_cluster_name()
-          if cluster_name and !cluster_name.empty?()
+          cluster_nodes = get_corosync_nodes()
+          if cluster_name and !cluster_name.empty?() and cluster_nodes and !cluster_nodes.empty?
             $logger.debug('Config files sync thread fetching')
             fetcher = Cfgsync::ConfigFetcher.new(
-              PCSAuth.getSuperuserAuth(), Cfgsync::get_cfg_classes(),
-              get_corosync_nodes(), cluster_name
+              PCSAuth.getSuperuserAuth(),
+              Cfgsync::get_cfg_classes(),
+              cluster_nodes,
+              cluster_name
             )
             cfgs_to_save, _ = fetcher.fetch()
             cfgs_to_save.each { |cfg_to_save|
@@ -211,6 +214,9 @@ helpers do
       if param == "disabled"
         meta_options << 'meta' << 'target-role=Stopped'
       end
+      if param == "force" and val
+        param_line << "--force"
+      end
     }
     return param_line + meta_options
   end
@@ -236,8 +242,13 @@ post '/run_pcs' do
     }
     return JSON.pretty_generate(result)
   end
-  # do not reveal potentialy sensitive information
-  command_decoded.delete('--debug')
+  # Do not reveal potentially sensitive information: remove --debug and all its
+  # prefixes since getopt parser in pcs considers them equal to --debug.
+  debug_items = ["--de", "--deb", "--debu", "--debug"]
+  command_sanitized = []
+  command_decoded.each { |item|
+    command_sanitized << item unless debug_items.include?(item)
+  }
 
   allowed_commands = {
     ['cluster', 'auth', '...'] => {
@@ -338,9 +349,9 @@ post '/run_pcs' do
   allowed = false
   command_settings = {}
   allowed_commands.each { |cmd, cmd_settings|
-    if command_decoded == cmd \
+    if command_sanitized == cmd \
       or \
-      (cmd[-1] == '...' and cmd[0..-2] == command_decoded[0..(cmd.length - 2)])
+      (cmd[-1] == '...' and cmd[0..-2] == command_sanitized[0..(cmd.length - 2)])
       then
         allowed = true
         command_settings = cmd_settings
@@ -369,7 +380,7 @@ post '/run_pcs' do
   options = {}
   options['stdin'] = std_in if std_in
   std_out, std_err, retval = run_cmd_options(
-    @auth_user, options, PCS, *command_decoded
+    @auth_user, options, PCS, *command_sanitized
   )
   result = {
     'status' => 'ok',
