@@ -237,16 +237,22 @@ function checkAddingNode(){
     $("#add_node_submit_btn").button("option", "disabled", false);
     return false;
   }
+  var port = $("#add_node_selector input.port").val().trim();
+  var data = {};
+  data["nodes"] = nodeName;
+  data["port-" + nodeName] = port;
 
   ajax_wrapper({
     type: 'GET',
     url: '/manage/check_pcsd_status',
-    data: {"nodes": nodeName},
+    data: data,
     timeout: pcs_timeout,
     success: function (data) {
       var mydata = jQuery.parseJSON(data);
       if (mydata[nodeName] == "Unable to authenticate") {
-        auth_nodes_dialog([nodeName], function(){$("#add_node_submit_btn").trigger("click");});
+        var nodes_to_auth = {};
+        nodes_to_auth[nodeName] = port;
+        auth_nodes_dialog(nodes_to_auth, function(){$("#add_node_submit_btn").trigger("click");});
         $("#add_node_submit_btn").button("option", "disabled", false);
       } else if (mydata[nodeName] == "Offline") {
         alert("Unable to contact node '" + nodeName + "'");
@@ -280,9 +286,24 @@ function create_node(form) {
   });
 }
 
+function create_resource_error_processing(error_message, form, update, stonith) {
+  var message = (
+    "Unable to " + (update ? "update " : "add ") + name + "\n" + error_message
+  );
+  if (message.indexOf('--force') == -1) {
+    alert(message);
+  }
+  else {
+    message = message.replace(', use --force to override', '');
+    if (confirm(message + "\n\nDo you want to force the operation?")) {
+      create_resource(form, update, stonith, true)
+    }
+  }
+}
+
 // If update is set to true we update the resource instead of create it
 // if stonith is set to true we update/create a stonith agent
-function create_resource(form, update, stonith) {
+function create_resource(form, update, stonith, force) {
   var data = {};
   $($(form).serializeArray()).each(function(index, obj) {
     data[obj.name] = obj.value;
@@ -297,6 +318,9 @@ function create_resource(form, update, stonith) {
   } else {
     name = "resource";
   }
+  if (force) {
+    data["force"] = force;
+  }
 
   ajax_wrapper({
     type: "POST",
@@ -306,7 +330,9 @@ function create_resource(form, update, stonith) {
     success: function(returnValue) {
       $('input.apply_changes').show();
       if (returnValue["error"] == "true") {
-        alert(returnValue["stderr"]);
+        create_resource_error_processing(
+          returnValue["stderr"], form, update, stonith
+        );
       } else {
         Pcs.update();
         if (!update) {
@@ -320,18 +346,9 @@ function create_resource(form, update, stonith) {
       }
     },
     error: function(xhr, status, error) {
-      if (update) {
-        alert(
-          "Unable to update " + name + " "
-          + ajax_simple_error(xhr, status, error)
-        );
-      }
-      else {
-        alert(
-          "Unable to add " + name + " "
-          + ajax_simple_error(xhr, status, error)
-        );
-      }
+      create_resource_error_processing(
+        ajax_simple_error(xhr, status, error), form, update, stonith
+      );
       $('input.apply_changes').show();
     }
   });
@@ -430,7 +447,7 @@ function verify_remove_nodes(node_id) {
 function verify_remove_resources(resource_id) {
   verify_remove(
     remove_resource, true, "resource_list", "dialog_verify_remove_resources",
-    "resource", "Remove resource(s)", "Resurce Removal", resource_id
+    "resource", "Remove resource(s)", "Resource Removal", resource_id
   );
 }
 
@@ -612,46 +629,76 @@ function disable_resource() {
   Pcs.resourcesContainer.disable_resource(curResource());
 }
 
-function cleanup_resource() {
-  var resource = curResource();
+function resource_stonith_cleanup_refresh(
+  resource, action_button_id, action_url, action_label, full_refresh
+) {
   if (resource == null) {
     return;
   }
-  fade_in_out("#resource_cleanup_link");
+  data = {"resource": resource}
+  if (full_refresh) {
+    data["full"] = 1
+  }
+  fade_in_out(action_button_id);
   ajax_wrapper({
     type: 'POST',
-    url: get_cluster_remote_url() + 'resource_cleanup',
-    data: {"resource": resource},
+    url: get_cluster_remote_url() + action_url,
+    data: data,
     success: function() {
     },
     error: function (xhr, status, error) {
       alert(
-        "Unable to cleanup resource '" + resource + "' "
+        "Unable to " + action_label + " resource '" + resource + "' "
         + ajax_simple_error(xhr, status, error)
       );
     }
   });
 }
 
+function cleanup_resource() {
+  resource_stonith_cleanup_refresh(
+    curResource(),
+    "#resource_cleanup_link",
+    "resource_cleanup",
+    "cleanup"
+  )
+}
+
 function cleanup_stonith() {
-  var resource = curStonith();
-  if (resource == null) {
-    return;
-  }
-  fade_in_out("#stonith_cleanup_link");
-  ajax_wrapper({
-    type: 'POST',
-    url: get_cluster_remote_url() + 'resource_cleanup',
-    data: {"resource": resource},
-    success: function() {
-    },
-    error: function (xhr, status, error) {
-      alert(
-        "Unable to cleanup resource '" + resource + "' "
-        + ajax_simple_error(xhr, status, error)
-      );
-    }
-  });
+  resource_stonith_cleanup_refresh(
+    curStonith(),
+    "#stonith_cleanup_link",
+    "resource_cleanup",
+    "cleanup"
+  )
+}
+
+function refresh_resource(refresh_supported) {
+  resource_stonith_cleanup_refresh(
+    curResource(),
+    "#resource_refresh_link",
+    /* previously, "refresh" was called "cleanup" */
+    refresh_supported ? "resource_refresh" : "resource_cleanup",
+    "refresh",
+    /* no way to set if we want to do the full (on all nodes) refresh from gui
+     * (yet);
+     * moreover the full refresh flag only works for refresh not for cleanup */
+    refresh_supported ? true : false
+  )
+}
+
+function refresh_stonith(refresh_supported) {
+  resource_stonith_cleanup_refresh(
+    curStonith(),
+    "#stonith_refresh_link",
+    /* previously, "refresh" was called "cleanup" */
+    refresh_supported ? "resource_refresh" : "resource_cleanup",
+    "refresh",
+    /* no way to set if we want to do the full (on all nodes) refresh from gui
+     * (yet);
+     * moreover the full refresh flag only works for refresh not for cleanup */
+    refresh_supported ? true : false
+  )
 }
 
 function checkExistingNode() {
@@ -659,11 +706,15 @@ function checkExistingNode() {
   $('input[name="node-name"]').each(function(i,e) {
     node = e.value;
   });
+  var port = $("#add_existing_cluster_form input.port").val().trim();
+  var data = {};
+  data["nodes"] = node;
+  data["port-" + node] = port;
 
   ajax_wrapper({
     type: 'GET',
     url: '/manage/check_pcsd_status',
-    data: {"nodes": node},
+    data: data,
     timeout: pcs_timeout,
     success: function (data) {
       mydata = jQuery.parseJSON(data);
@@ -676,25 +727,39 @@ function checkExistingNode() {
   });
 }
 
+function get_node_ports_object_from_create_new_cluster_dialog() {
+  var nodes = {}
+  $("#create_new_cluster_form tr.new_node").each(function(i, e) {
+    var node = $(e).find(".node").val().trim();
+    var port = $(e).find(".port").val().trim();
+    nodes[node] = port;
+  });
+  return nodes;
+}
+
 function checkClusterNodes() {
-  var nodes = [];
-  $('input[name^="node-"]').each(function(i,e) {
-    if (e.value != "") {
-      nodes.push(e.value)
+  var nodes = get_node_ports_object_from_create_new_cluster_dialog();
+  var node_list_str = Object.keys(nodes).join(",");
+  var request_data = {
+    "nodes": node_list_str,
+  };
+  $.each(nodes, function(node, port) {
+    if (port) {
+      request_data["port-" + node] = port;
     }
   });
 
   ajax_wrapper({
     type: 'GET',
     url: '/manage/check_pcsd_status',
-    data: {"nodes": nodes.join(",")},
+    data: request_data,
     timeout: pcs_timeout,
     success: function (data) {
       mydata = jQuery.parseJSON(data);
       ajax_wrapper({
         type: 'GET',
         url: '/manage/get_nodes_sw_versions',
-        data: {"nodes": nodes.join(",")},
+        data: {"nodes": node_list_str},
         timeout: pcs_timeout,
         success: function(data) {
           versions = jQuery.parseJSON(data);
@@ -784,9 +849,10 @@ function auth_nodes_dialog_update(dialog_obj, data) {
   return unauth_nodes;
 }
 
-function auth_nodes_dialog(unauth_nodes, callback_success, callback_success_one) {
+function auth_nodes_dialog(unauth_nodes, callback_success, callback_success_one, ports_required) {
   callback_success = typeof callback_success !== 'undefined' ? callback_success : null;
   callback_success_one = typeof callback_success_one !== 'undefined' ? callback_success_one : null;
+  ports_required = typeof ports_required !== 'undefined' ? ports_required : false;
 
   var buttonsOpts = [
     {
@@ -825,15 +891,16 @@ function auth_nodes_dialog(unauth_nodes, callback_success, callback_success_one)
       return false;
     }
   });
+  unauth_nodes_count = Object.keys(unauth_nodes).length;
 
-  if (unauth_nodes.length == 0) {
+  if (unauth_nodes_count == 0) {
     if (callback_success !== null) {
       callback_success();
     }
     return;
   }
 
-  if (unauth_nodes.length == 1) {
+  if (unauth_nodes_count == 1) {
     dialog_obj.find("#same_pass").hide();
   } else {
     dialog_obj.find("#same_pass").show();
@@ -843,8 +910,16 @@ function auth_nodes_dialog(unauth_nodes, callback_success, callback_success_one)
   }
 
   dialog_obj.find('#auth_nodes_list').empty();
-  unauth_nodes.forEach(function(node) {
-    dialog_obj.find('#auth_nodes_list').append("\t\t\t<tr><td>" + htmlEncode(node) + '</td><td><input type="password" name="' + htmlEncode(node) + '-pass"></td></tr>\n');
+  $.each(unauth_nodes, function(node, port) {
+    var html = "<tr><td>" + htmlEncode(node) + "</td><td>";
+    if (ports_required) {
+      html += ':<input type="text" size="5" name="port-' + htmlEncode(node) + '" placeholder="2224" />';
+    } else {
+      html += '<input type="hidden" name="port-' + htmlEncode(node) + '" value="' + htmlEncode(port) + '" />';
+    }
+    html += '</td><td><input type="password" name="' + htmlEncode(node) + '-pass"></td></tr>';
+
+    dialog_obj.find('#auth_nodes_list').append(html);
   });
 
 }
@@ -905,7 +980,9 @@ function update_existing_cluster_dialog(data) {
       });
       return;
     } else if (data[i] == "Unable to authenticate") {
-      auth_nodes_dialog([i], function() {$("#add_existing_submit_btn").trigger("click");});
+      var nodes_to_auth = {};
+      nodes_to_auth[i] = $("#add_existing_cluster_form input.port").val().trim();
+      auth_nodes_dialog(nodes_to_auth, function() {$("#add_existing_submit_btn").trigger("click");});
       $("#add_existing_submit_btn").button("option", "disabled", false);
       return;
     }
@@ -963,7 +1040,12 @@ function update_create_cluster_dialog(nodes, version_info) {
     });
 
     if (cant_auth_nodes.length > 0) {
-      auth_nodes_dialog(cant_auth_nodes, function(){$("#create_cluster_submit_btn").trigger("click")});
+      var ports = get_node_ports_object_from_create_new_cluster_dialog();
+      var unauth_nodes_with_ports = {};
+      $.each(cant_auth_nodes, function(i, node) {
+        unauth_nodes_with_ports[node] = ports[node];
+      });
+      auth_nodes_dialog(unauth_nodes_with_ports, function(){$("#create_cluster_submit_btn").trigger("click")});
       $("#create_cluster_submit_btn").button("option", "disabled", false);
       return;
     }
@@ -1144,7 +1226,8 @@ function create_cluster_add_nodes() {
 
   first_node = node_list.eq(0);
   new_node = first_node.clone();
-  $("input",new_node).attr("name", "node-"+(cur_num_nodes+1));
+  $("input[name=node-1]",new_node).attr("name", "node-"+(cur_num_nodes+1));
+  $("input[name=port-1]",new_node).attr("name", "port-"+(cur_num_nodes+1));
   $("input",new_node).val("");
   $("td", new_node).first().text("Node " + (cur_num_nodes+1)+ ":");
   new_node.insertAfter(node_list.last());
@@ -2278,6 +2361,10 @@ function resource_unclone(resource_id) {
   }
   show_loading_screen();
   var resource_obj = Pcs.resourcesContainer.get_resource_by_id(resource_id);
+  if (!resource_obj) {
+    console.log("Resource '" + resource_id + "' not found.");
+    return;
+  }
   if (resource_obj.get('class_type') == 'clone') {
     resource_id = resource_obj.get('member').get('id');
   }
@@ -2326,6 +2413,10 @@ function resource_change_group(resource_id, form) {
   }
   show_loading_screen();
   var resource_obj = Pcs.resourcesContainer.get_resource_by_id(resource_id);
+  if (!resource_obj) {
+    console.log("Resource '" + resource_id + "' not found.");
+    return;
+  }
   var data = {
     resource_id: resource_id
   };
