@@ -23,6 +23,7 @@ require 'pcsd_exchange_format.rb'
 # Commands for remote access
 def remote(params, request, auth_user)
   remote_cmd_without_pacemaker = {
+      :capabilities => method(:capabilities),
       :status => method(:node_status),
       :status_all => method(:status_all),
       :cluster_status => method(:cluster_status_remote),
@@ -102,6 +103,7 @@ def remote(params, request, auth_user)
       :resource_start => method(:resource_start),
       :resource_stop => method(:resource_stop),
       :resource_cleanup => method(:resource_cleanup),
+      :resource_refresh => method(:resource_refresh),
       :update_resource => method(:update_resource),
       :update_fence_device => method(:update_fence_device),
       :get_avail_resource_agents => method(:get_avail_resource_agents),
@@ -159,6 +161,12 @@ def remote(params, request, auth_user)
   end
 end
 
+def capabilities(params, request, auth_user)
+  return JSON.generate({
+    :pcsd_capabilities => CAPABILITIES_PCSD,
+  })
+end
+
 # provides remote cluster status to a local gui
 def cluster_status_gui(auth_user, cluster_name, dont_update_config=false)
   cluster_nodes = get_cluster_nodes(cluster_name)
@@ -1012,7 +1020,7 @@ def node_status(params, request, auth_user)
       'status?redirected=1',
       false,
       params.select { |k,_|
-        [:version, :operations].include?(k)
+        [:version, :operations, :skip_auth_check].include?(k)
       }
     )
   end
@@ -1033,20 +1041,22 @@ def node_status(params, request, auth_user)
 
   node = ClusterEntity::Node.load_current_node(crm_dom)
 
-  _,_,not_authorized_nodes = check_gui_status_of_nodes(
-    auth_user,
-    status[:known_nodes],
-    false,
-    3
-  )
+  if params[:skip_auth_check] != '1'
+    _,_,not_authorized_nodes = check_gui_status_of_nodes(
+      auth_user,
+      status[:known_nodes],
+      false,
+      3
+    )
 
-  if not_authorized_nodes.length > 0
-    node.warning_list << {
-      :message => 'Not authorized against node(s) ' +
-        not_authorized_nodes.join(', '),
-      :type => 'nodes_not_authorized',
-      :node_list => not_authorized_nodes,
-    }
+    if not_authorized_nodes.length > 0
+      node.warning_list << {
+        :message => 'Not authorized against node(s) ' +
+          not_authorized_nodes.join(', '),
+        :type => 'nodes_not_authorized',
+        :node_list => not_authorized_nodes,
+      }
+    end
   end
 
   version = params[:version] || '1'
@@ -1347,16 +1357,16 @@ end
 def auth(params, request, auth_user)
   token = PCSAuth.validUser(params['username'],params['password'], true)
   # If we authorized to this machine, attempt to authorize everywhere
-  node_list = []
+  nodes = {}
   if token and params["bidirectional"]
     params.each { |k,v|
       if k.start_with?("node-")
-        node_list.push(v)
+        nodes[v] = params["port-#{v}"]
       end
     }
-    if node_list.length > 0
+    if nodes.length > 0
       pcs_auth(
-        auth_user, node_list, params['username'], params['password'],
+        auth_user, nodes, params['username'], params['password'],
         params["force"] == "1"
       )
     end
@@ -1431,6 +1441,24 @@ def resource_cleanup(params, request, auth_user)
   end
 end
 
+def resource_refresh(params, request, auth_user)
+  if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
+    return 403, 'Permission denied'
+  end
+  cmd = [PCS, "resource", "refresh", params[:resource]]
+  if params[:full] == '1'
+    cmd << "--full"
+  end
+  stdout, stderr, retval = run_cmd(auth_user, *cmd)
+  if retval == 0
+    return JSON.generate({"success" => "true"})
+  else
+    return JSON.generate(
+      {"error" => "true", "stdout" => stdout, "stderror" => stderr}
+    )
+  end
+end
+
 def resource_start(params, request, auth_user)
   if not allowed_for_local_cluster(auth_user, Permissions::WRITE)
     return 403, 'Permission denied'
@@ -1466,7 +1494,7 @@ def update_resource (params, request, auth_user)
       end
       resource_group = params[:resource_group]
     end
-    if params[:resource_type] == "ocf:pacemaker:remote"
+    if params[:resource_type] == "ocf:pacemaker:remote" and not cmd.include?("--force")
       # Workaround for Error: this command is not sufficient for create remote
       # connection, use 'pcs cluster node add-remote', use --force to override.
       # It is not possible to specify meta attributes so we don't need to take
@@ -2083,7 +2111,16 @@ def get_cluster_tokens(params, request, auth_user)
   on, off = get_nodes
   nodes = on + off
   nodes.uniq!
-  return [200, JSON.generate(get_tokens_of_nodes(nodes))]
+  token_file_data = read_token_file()
+  tokens = token_file_data.tokens.select {|k,v| nodes.include?(k)}
+  if params["with_ports"] != '1'
+    return [200, JSON.generate(tokens)]
+  end
+  data = {
+    :tokens => tokens,
+    :ports => token_file_data.ports.select {|k,v| nodes.include?(k)},
+  }
+  return [200, JSON.generate(data)]
 end
 
 def save_tokens(params, request, auth_user)
@@ -2093,18 +2130,23 @@ def save_tokens(params, request, auth_user)
   end
 
   new_tokens = {}
+  new_ports = {}
 
   params.each{|nodes|
     if nodes[0].start_with?"node:" and nodes[0].length > 5
       node = nodes[0][5..-1]
-      token = nodes[1]
-      new_tokens[node] = token
+      new_tokens[node] = nodes[1]
+      port = (params["port:#{node}"] || '').strip
+      if port == ''
+        port = nil
+      end
+      new_ports[node] = port
     end
   }
 
   tokens_cfg = Cfgsync::PcsdTokens.from_file()
   sync_successful, sync_responses = Cfgsync::save_sync_new_tokens(
-    tokens_cfg, new_tokens, get_corosync_nodes(), $cluster_name
+    tokens_cfg, new_tokens, get_corosync_nodes(), $cluster_name, new_ports
   )
 
   if sync_successful
